(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    101623,       2707]*)
(*NotebookOutlinePosition[    102376,       2734]*)
(*  CellTagsIndexPosition[    102332,       2730]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox["Musica",
  FontSize->50]], "Title",
  Evaluatable->False,
  TextAlignment->Center],

Cell["version 0.9beta", "Commentary",
  TextAlignment->Right],

Cell[TextData[{
  "Create music with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "."
}], "Subtitle",
  Evaluatable->False,
  TextAlignment->Center],

Cell[TextData[StyleBox["Costis Merziotis", "Text"]], "Section 1",
  TextAlignment->Right],

Cell[CellGroupData[{

Cell["Initialization", "Section"],

Cell[BoxData[{
    \(<< musica.m\), "\[IndentingNewLine]", 
    \(<< Graphics`Graphics`\)}], "Input",
  ShowCellBracket->False,
  ShowGroupOpenCloseIcon->True,
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is one of the leading tools in technical computation for a long time now. \
Whereas audio support is standard in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and there are some great packages for audio manipulation and \
experimentation, there is nothing (as far as I know) covering the vast area \
of MIDI: the language of electronic musical instruments. Musica is a package \
that will help you use the power of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " for the creation of music. The only thing you need is some kind of \
software that can play .mid files such as Windows Media Player, Winamp or any \
sequencer like Cakewalk, Cubase, Logic etc. and a device that can receive \
MIDI messages such as: a simple Sound Card, a Synth, a Software Synth, an \
Effects Processor or a Mixer with MIDI capabilities.\n\nMusica is not for \
begginers, if you don't know what MIDI is and have never used a synth or \
sequencer it will be pretty useless for you. However if you have some \
experience with synths and sequencers it is fairly easy to use. You may ask: \
\"Why would I use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to create MIDI files when I can do that easily with my sequencer?\". \
Well, a sequencer is pretty good at recording your performance and then \
applying simple editing functions such as copy, paste or quantize, but the \
versatility of a programming language like ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "allows you to do things that no sequencer would ever dream of. The only \
limit here is your programming skills and your imagination. The possibilities \
are endless. Here are some of the uses of Musica:\n- Algorithmic Music: use \
any algorithm to produce or edit music. Fractals, automata, any function you \
can imagine can be translated to music!\n- Advanced Sound Design: use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s versatility to create unique MIDI sequences, Sound Effects or templates \
for use with your performances.\n- Advanced MIDI Editing: edit any MIDI \
sequence easily and with stunning flexibility. Create and apply MIDI effects \
to your sequences.\n- Music Analysis: analyse music data from a mathematical \
viewpoint. \n- Testing: test your MIDI gear, push it to its limits.\n- Music \
Translation: translate music to any other primitive ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can handle. For example you can transform notes to 3D objects.\n- \
Experimentation: experiment with the human perception of sound and music.\n\
And that is only a sample of what you can do combining the power and \
flexibility of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " with MIDI via Musica.\n\nMusica is as easy as it can be: MIDI events can \
be declared simply and easily, MIDI editing can be done by applying usual ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " rules to event lists and event sequences can be produced by easy \
Table-like commands. A basic ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " knowledge is enough to get great results.\nMy wish is that this package \
will become a hands-on introduction to the world that lies between \
Mathematics and Music for the people that are interested in both. \n\nThere \
is a minimalistic philosophy in the design of Musica. Instead of giving \
numerous dedicated functions of limited purpose, the whole concept is to be \
able to use the built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions to manipulate MIDI data. This has many advantages: there is no \
need to learn many new functions and their syntaxes, built-in functions are \
faster, you are not dictated the way to do something and you have the full ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " potential in your hands. Offcourse this means you have to do a little bit \
more programming yourself. Don't be alarmed though, MIDI manipulation in \
Musica is as easy as regular list manipulation (which is probably one of the \
first things you learn in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "). This notebook contains far more examples than you will need to \
understand the whole Musica philosophy.\n\nThe most important feature of \
Musica is its generality: it supports the full format 0 MIDI file protocol so \
every possible MIDI file can be imported or exported. If we take into account \
the flexibility of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " itself, every algorithm can be used to produce or edit MIDI data. Few \
systems provide this kind of flexibility in MIDI file manipulation with such \
ease."
}], "Text"],

Cell[CellGroupData[{

Cell["Limitations", "Subsection",
  Evaluatable->False],

Cell[TextData[{
  "- Musica is limited to format 0 MIDI files. Implementing  format 1 MIDI \
files would only complicate things. The musical content is exactly the same \
in both formats so there is no real need to use format 1 files in a program \
that is not a sequencer. However, as you probably know, you can convert \
between the two formats with any popular sequencer, and there are also some \
freeware programs that do the trick.\n- Musica is designed to be fast, but as \
a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-only (non-Mathlink) program it is still slower than any dedicated music \
program. I used the low level Read fuction instead of ReadListBinary to speed \
up the reading of large MIDI files while at the same time conserving memory. \
It is recommended that you import small MIDI files. You should also keep your \
eventlists to reasonable size but this depends on your system's memory. \
Nevertheless Musica can handle large MIDI files if you are prepared to wait a \
bit. \n- Musica does not produce any error messages at this point. If \
something goes wrong check the syntax of your command and check that all \
arguments are in the legal range.\n- None of the algorithms of the examples \
are optimized in any way. The examples are only for illustratory purposes, I \
selected algorithms that are short and easy to understand while they give you \
an idea of how you can write your programs."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Tutorial", "Section"],

Cell[TextData[{
  "Note: All examples export the same file \"output.mid\" so you don't end up \
with a bunch of unwanted .mid files. You can find that file in the root ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " directory. Every time you export something new the file is overwritten \
and you have to reload it in your sequencer or player. If you want to keep a \
.mid file exported from one of the examples just change the second argument \
of the ExportMIDI command to a different file name."
}], "Commentary"],

Cell[CellGroupData[{

Cell["Creating, exporting and importing Eventlists.", "Subsection"],

Cell[TextData[{
  "The whole concept of Musica is simple. The basic object here is the \
Eventlist. You can export an Eventlist to a MIDI file or import a MIDI file \
to an Eventlist. An Eventlist is a simple ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " list consisting of Events. An Event is a list containing two elements: \
the time of the event and a MIDI message. A Musica Eventlist is as you have \
probably guessed similar to the eventlists found in any sequencer. There is \
one difference though: event time is given in ticks and not in the standard \
Meters:Beats:Ticks or SMPTE notation. This facilitates the mathematical \
manipulation of events as will become apparent later on. The MIDI message is \
given like a simple function with arguments the values of the message. Here's \
an example of an Event:"
}], "Text"],

Cell[BoxData[
    \(event1 = {1540, PitchBend[100, 2]}\)], "Input",
  Evaluatable->False],

Cell["\<\
This represents a Pitch Bend message that occurs 1540 ticks after the start \
of the file. The first argument represents the value of the Pitch Bend and \
the second the channel of the event. 
Here is the complete list of the MIDI messages that can be present in a MIDI \
file as implemented in Musica. For full documetation on each message just \
type ? followed by the name of the message.\
\>", "Text"],

Cell["\<\
NoteOn[Note Number,Velocity,Channel]
NoteOff[Note Number,Velocity,Channel]
KeyAftertouch[Note Number,Value,Channel]
Controller[Controller Number,Value,Channel]
ProgramChange[Program Number,Channel]
PitchBend[Pitch Bend Value,Channel]
ChannelAftertouch[Value,Channel]
Sysex[Data List]\
\>", "Program"],

Cell["The ranges for the arguments of the above messages are:", "Text"],

Cell["\<\
Note Number,Velocity,Value,Controller Number: 0 to 127
Program Number: 1 to 128
Channel: 1 to 16
Pitch Bend Value: -8192 to 8191\
\>", "Program"],

Cell["\<\
Except from these messages a MIDI file can contain Metaevents. These are \
messages useful to the sequencer that are used exactly like MIDI messages. \
The general syntax of a Metaevent is \
\>", "Text"],

Cell[BoxData[
    \(MetaEvent[Type\ Number, Data\ List]\)], "DisplayFormula"],

Cell["\<\
However this is for advanced use only, most popular Metaevents are directly \
implemented in Musica. This is the full list. Again ? followed by the \
Metaevent name gives further details.\
\>", "Text"],

Cell["\<\
Tempo[BPM]
TimeSignature[Nominator,Denominator]
KeySignature[Number of Sharps or Flats,Mm]
TextEvent[String]
Copyright[String]
TrackName[String]
InstrumentName[String]
Lyric[String]
Marker[String]
CuePoint[String]
EndOfTrack\
\>", "Program"],

Cell["\<\
For convenience a Note message is included which contains a duration argument \
and can even accept MIDI note names apart from MIDI note number. This in fact \
corresponds to 2 MIDI messages one NoteOn and one NoteOff (NoteOn with 0 \
velocity) after a number of ticks defined by the duration argument. This is \
the basic message you will have to use to produce music. Here is the general \
syntax followed by some examples:\
\>", "Text"],

Cell["\<\
Note[Note Number or Note Name,Duration,Velocity,Channel]

Note[C5,123,100,1]
Note[65,quartertriplet,100,2]
Note[D#6,2whole+3quarter,60,16]\
\>", "Program"],

Cell["\<\
As you may have noticed in the last two examples standard musical durations \
and functions of them can be used as arguments. These are automatically \
replaced by their corresponding number of ticks according to the MIDI file \
division (PPQ) given when an EventList is sorted or exported. The PPQ is the \
number of ticks per quarter. Here is the full list of durations followed by \
an example of an event that uses durations extensively: \
\>", "Text"],

Cell["\<\
whole
half
halftriplet
quarter
quartertriplet
eighth
eighthtriplet
sixteenth
sixteenthtriplet
thirtysecond
thirtysecondtriplet
tick\
\>", "Program"],

Cell[BoxData[
    \(event2 = {10\ whole + 3  quarter + 80  tick, 
        Note["\<C5\>", quartertriplet, 100, 1]}\)], "Input"],

Cell["\<\
Let us now construct an eventlist containing every possible MIDI message or \
Metaevent.\
\>", "Text"],

Cell[BoxData[
    \(\(testeventlist = {\[IndentingNewLine]{0, 
            Note[54, quarter, 127, 1]}, \[IndentingNewLine]{whole, 
            Note["\<C5\>", eighth, 100, 2]}, \[IndentingNewLine]{whole + 
              quarter, Controller[10, 64, 1]}, \[IndentingNewLine]{4  whole, 
            PitchBend[0, 1]}, \[IndentingNewLine]{4  whole + quarter, 
            PitchBend[\(-8192\), 1]}, \[IndentingNewLine]{5  whole, 
            ProgramChange[10, 1]}, \[IndentingNewLine]{6  whole, 
            KeyAftertouch[16, 111, 1]}, \[IndentingNewLine]{4  whole, 
            ChannelAftertouch[12, 1]}, \[IndentingNewLine]{whole + 
              3  quarter, 
            Sysex[{16^^f0, 43, 78, 5, 16^^f7}]}, \[IndentingNewLine]{0, 
            Tempo[120]}, \[IndentingNewLine]{2  whole, 
            Tempo[200.76]}, \[IndentingNewLine]{2  whole, 
            Marker["\<Tempo Change\>"]}, \[IndentingNewLine]{0, 
            TrackName["\<My Song\>"]}, \[IndentingNewLine]{0, 
            Copyright["\<This is Copyright\>"]}, \[IndentingNewLine]{0, 
            InstrumentName["\<This is the Instrument\>"]}, \
\[IndentingNewLine]{whole, Lyric["\<Lyric!!\>"]}, \[IndentingNewLine]{0, 
            CuePoint["\<The Cue Point\>"]}, \[IndentingNewLine]{2  whole, 
            TextEvent["\<Text Event\>"]}, \[IndentingNewLine]{whole, 
            TimeSignature[6, 8]}, \[IndentingNewLine]{0, 
            KeySignature[0, 0]}, \[IndentingNewLine]{whole, 
            KeySignature[7, 0]}, \[IndentingNewLine]{2  whole, 
            KeySignature[\(-7\), 1]}\[IndentingNewLine]};\)\)], "Input"],

Cell["\<\
As you may have noticed this eventlist is not sorted in any way. You can use \
the function SortEventList to sort it in chronological order. The first \
argument for SortEventList is the Eventlist itself while the second is the \
PPQ (division). If you omit the second argument PPQ defaults to 192. Notice \
how durations get replaced by ticks. Using ColumnForm makes the list easier \
to read.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SortEventList[testeventlist, 120] // ColumnForm\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\({0, Note[54, 120, 127, 1]}\)},
          {\({0, Tempo[120]}\)},
          {\({0, TrackName["My Song"]}\)},
          {\({0, Copyright["This is Copyright"]}\)},
          {\({0, InstrumentName["This is the Instrument"]}\)},
          {\({0, CuePoint["The Cue Point"]}\)},
          {\({0, KeySignature[0, 0]}\)},
          {\({480, Note[60, 60, 100, 2]}\)},
          {\({480, Lyric["Lyric!!"]}\)},
          {\({480, TimeSignature[6, 8]}\)},
          {\({480, KeySignature[7, 0]}\)},
          {\({600, Controller[10, 64, 1]}\)},
          {\({840, Sysex[{240, 43, 78, 5, 247}]}\)},
          {\({960, Tempo[200.76`]}\)},
          {\({960, Marker["Tempo Change"]}\)},
          {\({960, TextEvent["Text Event"]}\)},
          {\({960, KeySignature[\(-7\), 1]}\)},
          {\({1920, PitchBend[0, 1]}\)},
          {\({1920, ChannelAftertouch[12, 1]}\)},
          {\({2040, PitchBend[\(-8192\), 1]}\)},
          {\({2400, ProgramChange[10, 1]}\)},
          {\({2880, KeyAftertouch[16, 111, 1]}\)}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      ColumnForm[ {{0, 
        Note[ 54, 120, 127, 1]}, {0, 
        Tempo[ 120]}, {0, 
        TrackName[ "My Song"]}, {0, 
        Copyright[ "This is Copyright"]}, {0, 
        InstrumentName[ "This is the Instrument"]}, {0, 
        CuePoint[ "The Cue Point"]}, {0, 
        KeySignature[ 0, 0]}, {480, 
        Note[ 60, 60, 100, 2]}, {480, 
        Lyric[ "Lyric!!"]}, {480, 
        TimeSignature[ 6, 8]}, {480, 
        KeySignature[ 7, 0]}, {600, 
        Controller[ 10, 64, 1]}, {840, 
        Sysex[ {240, 43, 78, 5, 247}]}, {960, 
        Tempo[ 200.75999999999999]}, {960, 
        Marker[ "Tempo Change"]}, {960, 
        TextEvent[ "Text Event"]}, {960, 
        KeySignature[ -7, 1]}, {1920, 
        PitchBend[ 0, 1]}, {1920, 
        ChannelAftertouch[ 12, 1]}, {2040, 
        PitchBend[ -8192, 1]}, {2400, 
        ProgramChange[ 10, 1]}, {2880, 
        KeyAftertouch[ 16, 111, 1]}}],
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Now we are ready to export the Eventlist to a MIDI file. To do so, we use the \
ExportMIDI function which accepts 2 arguments: the first is the Eventlist and \
the second the name of the file (usually a .mid file). The Eventlist need not \
be sorted.\
\>", "Text"],

Cell[BoxData[
    \(ExportMIDI[testeventlist, "\<output.mid\>"]\)], "Input"],

Cell["\<\
If you want to use a different PPQ (ticks per quarter) other than the default \
192 for your exported file you can use the PPQ option. Here we export the \
same file with PPQ set to 480.\
\>", "Text"],

Cell[BoxData[
    \(ExportMIDI[testeventlist, "\<output.mid\>", PPQ \[Rule] 480]\)], "Input"],

Cell[TextData[{
  "You can now open the file test.mid with your favorite sequencer and view \
the sequencers eventlist in comparison with the sorted Eventlist above. Be \
warned that some Metaevents are interpreted differently depending on the \
sequencer for example a Cue Point or Text Event can be interpreted as \
Markers. Note the tempo, key and signature changes. Well this was your first \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " created MIDI file: easy isn't it?"
}], "Text"],

Cell["\<\
Let us now import the same file. The function ImportMIDI reads the file and \
returns an Eventlist.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ImportMIDI["\<output.mid\>"] // ColumnForm\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Format: "\[InvisibleSpace]0\),
      SequenceForm[ "Format: ", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Tracks: "\[InvisibleSpace]1\),
      SequenceForm[ "Tracks: ", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("PPQ: "\[InvisibleSpace]192\),
      SequenceForm[ "PPQ: ", 192],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\({0, Note[54, 192, 127, 1]}\)},
          {\({0, Tempo[120.`]}\)},
          {\({0, TrackName["My Song"]}\)},
          {\({0, Copyright["This is Copyright"]}\)},
          {\({0, InstrumentName["This is the Instrument"]}\)},
          {\({0, CuePoint["The Cue Point"]}\)},
          {\({0, KeySignature[0, 0]}\)},
          {\({768, Note[60, 96, 100, 2]}\)},
          {\({768, Lyric["Lyric!!"]}\)},
          {\({768, TimeSignature[6, 8, 12, 8]}\)},
          {\({768, KeySignature[7, 0]}\)},
          {\({960, Controller[10, 64, 1]}\)},
          {\({1344, Sysex[{240, 43, 78, 5, 247}]}\)},
          {\({1536, Tempo[200.76021200278387`]}\)},
          {\({1536, Marker["Tempo Change"]}\)},
          {\({1536, TextEvent["Text Event"]}\)},
          {\({1536, KeySignature[\(-7\), 1]}\)},
          {\({3072, PitchBend[0, 1]}\)},
          {\({3072, ChannelAftertouch[12, 1]}\)},
          {\({3264, PitchBend[\(-8192\), 1]}\)},
          {\({3840, ProgramChange[10, 1]}\)},
          {\({4608, KeyAftertouch[16, 111, 1]}\)}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnAlignments->{Left}],
      ColumnForm[ {{0, 
        Note[ 54, 192, 127, 1]}, {0, 
        Tempo[ .12*^3]}, {0, 
        TrackName[ "My Song"]}, {0, 
        Copyright[ "This is Copyright"]}, {0, 
        InstrumentName[ "This is the Instrument"]}, {0, 
        CuePoint[ "The Cue Point"]}, {0, 
        KeySignature[ 0, 0]}, {768, 
        Note[ 60, 96, 100, 2]}, {768, 
        Lyric[ "Lyric!!"]}, {768, 
        TimeSignature[ 6, 8, 12, 8]}, {768, 
        KeySignature[ 7, 0]}, {960, 
        Controller[ 10, 64, 1]}, {1344, 
        Sysex[ {240, 43, 78, 5, 247}]}, {1536, 
        Tempo[ 200.76021200278387]}, {1536, 
        Marker[ "Tempo Change"]}, {1536, 
        TextEvent[ "Text Event"]}, {1536, 
        KeySignature[ -7, 1]}, {3072, 
        PitchBend[ 0, 1]}, {3072, 
        ChannelAftertouch[ 12, 1]}, {3264, 
        PitchBend[ -8192, 1]}, {3840, 
        ProgramChange[ 10, 1]}, {4608, 
        KeyAftertouch[ 16, 111, 1]}}],
      Editable->False]], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Algorithmic creation of Eventlists.", "Subsection"],

Cell["\<\
What we have seen up to now, can be easily done with a sequencer. In this \
section we will learn the basic functions that are used to create Eventlists \
algorithmically. The first and most general function is GenerateEventList. \
Its use is similar to the built-in Table function. Here is the general \
syntax:\
\>", "Text"],

Cell["\<\
GenerateEventList[Event1,Event2,...,{i,imin,imax},{j,jmin,jmax},...,PPQ]\
\>", "Program"],

Cell["\<\
The PPQ argument is used in the sorting of the result and can be omited just \
as in SortEventList if you want it to take the default value 192. 
It is not required that the events generated are in chronological order - the \
result will be sorted chronologically. Here is an example:\
\>", "Text"],

Cell[BoxData[
    \(allprograms = 
      GenerateEventList[\[IndentingNewLine]{i\ eighth, 
          ProgramChange[i + 1, 1]}, {i\ eighth + sixteenth, 
          Note["\<C5\>", sixteenth, 100, 1]}, \[IndentingNewLine]{i, 0, 
          127}]\)], "Input",
  CellLabel->"In[3]:="],

Cell["\<\
This Eventlist demonstrates all the voices of the first bank of a synth by \
simply creating a sequence of program changes and some test notes after each \
change. Notice the use of durations in conjunction with the iterator. It \
should be apparent now that with an unlimited number of iterators and events \
and the use of any function of the iterators in event time and/or as any \
argument of any MIDI message, the flexibility of this function is stunning. \
The functions that denote each events time need not be ordered; the final \
result is sorted automatically. You should already know how to export this to \
a midi file:\
\>", "Text"],

Cell[BoxData[
    \(ExportMIDI[allprograms, "\<output.mid\>"]\)], "Input"],

Cell["\<\
The second fuction that is used to generate Eventlists is EventSequence. This \
is not as general as GenerateEventList and it's used to create sequences of \
events where each successive event happens some predefined time from the last \
one. The general syntax is:\
\>", "Text"],

Cell[BoxData[
    \(EventSequence[MIDI\ Message\ or\ Metaevent\ , Step, {i, imax, imin}, 
      PPQ]\)], "DisplayFormula"],

Cell["\<\
Step is a function that denotes the interval in ticks between two successive \
events, and the first argument should be a MIDI Message or a Metaevent and \
not a complete Event as in GenerateEventList. Here's an example:\
\>", "Text"],

Cell[BoxData[{
    \(\(sinenotes = 
        EventSequence[
          Note[Round[63\ Sin[2  Pi\ i/100]] + 64, eighth, 100, 1], 
          eighth, {i, 0, 100}];\)\), "\[IndentingNewLine]", 
    \(ExportMIDI[sinenotes, "\<output.mid\>"]\)}], "Input"],

Cell["\<\
This is a sequence of Note Events that resembles a sine wave when viewed in a \
sequencer with piano roll feature. The round function is used to return an \
Integer as an argument. Each note is an eighth. All these Events happen in \
intervals that correspond to an eighth (the step function is the constant \
eighth). Here is an example that uses a non-constant step function:\
\>", "Text"],

Cell[BoxData[{
    \(bouncestep[i_] := 
      sixteenth + Round[40\ Cos[2  Pi\ i/100]]\), "\[IndentingNewLine]", 
    \(\(bounce = \[IndentingNewLine]EventSequence[
          Note["\<C5\>", bouncestep[i], 100, 1], 
          bouncestep[i], {i, 0, 100}];\)\), "\[IndentingNewLine]", 
    \(ExportMIDI[bounce, "\<output.mid\>"]\)}], "Input"],

Cell[TextData[{
  "This sounds like a bouncing ball. Notice that if the function used for the \
Note duration is the same with the Step function then each note starts \
exactly when the last one finishes.\nGenerateEventList and EventSequence is \
all you need to create Eventlists based on any ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " algorithm. Now let's see how we can manipulate Eventlists. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Manipulation of Eventlists.", "Subsection"],

Cell[TextData[{
  "Eventlists can be manipulated like any regular ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " list. First of all let's construct a sample Eventlist."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(el = 
      SortEventList[{{0, TrackName["\<Sample Eventlist\>"]}, {0, 
            Controller[10, 0, 1]}, {0, Controller[10, 127, 2]}, {0, 
            Note["\<C5\>", quarter, 50, 1]}, {quarter, 
            Note["\<D5\>", quarter, 100, 1]}, {2  quarter, 
            Note["\<E5\>", quarter, 50, 1]}, {0, 
            Note["\<E5\>", quarter, 100, 2]}, {quarter, 
            Note["\<F5\>", quarter, 50, 2]}, {2  quarter, 
            Note["\<G5\>", quarter, 100, 2]}}]\)], "Input"],

Cell[BoxData[
    \({{0, TrackName["Sample Eventlist"]}, {0, Controller[10, 0, 1]}, {0, 
        Controller[10, 127, 2]}, {0, Note[60, 192, 50, 1]}, {0, 
        Note[64, 192, 100, 2]}, {192, Note[62, 192, 100, 1]}, {192, 
        Note[65, 192, 50, 2]}, {384, Note[64, 192, 50, 1]}, {384, 
        Note[67, 192, 100, 2]}}\)], "Output"]
}, Open  ]],

Cell["\<\
You can extract Events with the built in Cases function. Make sure that you \
have sorted your Eventlist with SortEventList before any operations so that \
durations are substituted by ticks. Here are some examples of creating new \
Eventlists by extracting Events from existing ones:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Cases[el, {_, _Note}]\)], "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    \({{0, Note[60, 192, 50, 1]}, {0, Note[64, 192, 100, 2]}, {192, 
        Note[62, 192, 100, 1]}, {192, Note[65, 192, 50, 2]}, {384, 
        Note[64, 192, 50, 1]}, {384, Note[67, 192, 100, 2]}}\)], "Output",
  CellLabel->"Out[22]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Cases[el, {t_ /; t \[GreaterEqual] \ 192, _}]\)], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    \({{192, Note[62, 192, 100, 1]}, {192, Note[65, 192, 50, 2]}, {384, 
        Note[64, 192, 50, 1]}, {384, Note[67, 192, 100, 2]}}\)], "Output",
  CellLabel->"Out[23]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Cases[el, {_, Controller[_, x_ /; x > 64, _]}]\)], "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[
    \({{0, Controller[10, 127, 2]}}\)], "Output",
  CellLabel->"Out[24]="]
}, Open  ]],

Cell["\<\
For convenience some Event extracting functions have been included. \
MIDIChannel returns all Events in a specific MIDI channel. ChannelEvents \
returns all Events that are associated with MIDI channels ie. all Events that \
contain MIDI messages other than Sysex. MetaEvents returns all Metaevents. \
SysexEvents returns all Sysex Events. Here is the syntax for each function \
followed by some examples:\
\>", "Text"],

Cell["\<\
MIDIChannel[Eventlist,Channel]
ChannelEvents[Eventlist]
MetaEvents[EventList]
SysexEvents[Eventlist]\
\>", "Program"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MIDIChannel[el, 2]\)], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    \({{0, Controller[10, 127, 2]}, {0, Note[64, 192, 100, 2]}, {192, 
        Note[65, 192, 50, 2]}, {384, Note[67, 192, 100, 2]}}\)], "Output",
  CellLabel->"Out[25]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ChannelEvents[el]\)], "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    \({{0, Controller[10, 0, 1]}, {0, Controller[10, 127, 2]}, {0, 
        Note[60, 192, 50, 1]}, {0, Note[64, 192, 100, 2]}, {192, 
        Note[62, 192, 100, 1]}, {192, Note[65, 192, 50, 2]}, {384, 
        Note[64, 192, 50, 1]}, {384, Note[67, 192, 100, 2]}}\)], "Output",
  CellLabel->"Out[26]="]
}, Open  ]],

Cell["\<\
You can join Eventlists with the built-in Join function or the Union function \
if you don't want common Events to be repeated. In the same way you can treat \
EventLists as sets and do set operations on them.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SortEventList[Join[MetaEvents[el], el]]\)], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    \({{0, TrackName["Sample Eventlist"]}, {0, 
        TrackName["Sample Eventlist"]}, {0, Controller[10, 0, 1]}, {0, 
        Controller[10, 127, 2]}, {0, Note[60, 192, 50, 1]}, {0, 
        Note[64, 192, 100, 2]}, {192, Note[62, 192, 100, 1]}, {192, 
        Note[65, 192, 50, 2]}, {384, Note[64, 192, 50, 1]}, {384, 
        Note[67, 192, 100, 2]}}\)], "Output",
  CellLabel->"Out[27]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SortEventList[Union[el, MetaEvents[el]]]\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \({{0, Controller[10, 0, 1]}, {0, Controller[10, 127, 2]}, {0, 
        Note[60, 192, 50, 1]}, {0, Note[64, 192, 100, 2]}, {0, 
        TrackName["Sample Eventlist"]}, {192, Note[62, 192, 100, 1]}, {192, 
        Note[65, 192, 50, 2]}, {384, Note[64, 192, 50, 1]}, {384, 
        Note[67, 192, 100, 2]}}\)], "Output",
  CellLabel->"Out[28]="]
}, Open  ]],

Cell["\<\
Removing Events is done in the same way as extracting them but using \
DeleteCases instead of Cases.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DeleteCases[el, {_, _Controller}]\)], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \({{0, TrackName["Sample Eventlist"]}, {0, Note[60, 192, 50, 1]}, {0, 
        Note[64, 192, 100, 2]}, {192, Note[62, 192, 100, 1]}, {192, 
        Note[65, 192, 50, 2]}, {384, Note[64, 192, 50, 1]}, {384, 
        Note[67, 192, 100, 2]}}\)], "Output",
  CellLabel->"Out[29]="]
}, Open  ]],

Cell["\<\
You can transform any Event to any other or to a sequence of Events by \
applying rules to the Eventlist and using the built-in Sequence function.\
\>", "Text"],

Cell["Here all Note messages are raised by an octave.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(el /. 
      Note[n_, d_, v_, c_] \[RuleDelayed] 
        Note[n + 12, d, Round[v/2], c]\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    \({{0, TrackName["Sample Eventlist"]}, {0, Controller[10, 0, 1]}, {0, 
        Controller[10, 127, 2]}, {0, Note[72, 192, 25, 1]}, {0, 
        Note[76, 192, 50, 2]}, {192, Note[74, 192, 50, 1]}, {192, 
        Note[77, 192, 25, 2]}, {384, Note[76, 192, 25, 1]}, {384, 
        Note[79, 192, 50, 2]}}\)], "Output",
  CellLabel->"Out[30]="]
}, Open  ]],

Cell["\<\
In this example Note Events are translated to Controller 10 (pan) Events \
according to their note number.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(el\  /. 
      Note[n_, d_, v_, c_] \[RuleDelayed] Controller[10, n, c]\)], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \({{0, TrackName["Sample Eventlist"]}, {0, Controller[10, 0, 1]}, {0, 
        Controller[10, 127, 2]}, {0, Controller[10, 60, 1]}, {0, 
        Controller[10, 64, 2]}, {192, Controller[10, 62, 1]}, {192, 
        Controller[10, 65, 2]}, {384, Controller[10, 64, 1]}, {384, 
        Controller[10, 67, 2]}}\)], "Output",
  CellLabel->"Out[31]="]
}, Open  ]],

Cell["Here all Note Events are moved one quarter later.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SortEventList[
      el /. {t_, e_Note} \[RuleDelayed] {t + quarter, e}]\)], "Input"],

Cell[BoxData[
    \({{0, TrackName["Sample Eventlist"]}, {0, Controller[10, 0, 1]}, {0, 
        Controller[10, 127, 2]}, {192, Note[60, 192, 50, 1]}, {192, 
        Note[64, 192, 100, 2]}, {384, Note[62, 192, 100, 1]}, {384, 
        Note[65, 192, 50, 2]}, {576, Note[64, 192, 50, 1]}, {576, 
        Note[67, 192, 100, 2]}}\)], "Output",
  CellLabel->"Out[32]="]
}, Open  ]],

Cell["\<\
In the next example all Note Events are substituted by two Notes of pitch an \
octave higher and an octave lower respectively. The Sequence function is used \
to enclose more than one Events.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SortEventList[
      el /. {t_, Note[n_, d_, v_, c_]} \[RuleDelayed] 
          Sequence[{t, Note[n - 12, d, v, c]}, {t, 
              Note[n + 12, d, v, c]}]]\)], "Input"],

Cell[BoxData[
    \({{0, TrackName["Sample Eventlist"]}, {0, Controller[10, 0, 1]}, {0, 
        Controller[10, 127, 2]}, {0, Note[48, 192, 50, 1]}, {0, 
        Note[72, 192, 50, 1]}, {0, Note[52, 192, 100, 2]}, {0, 
        Note[76, 192, 100, 2]}, {192, Note[50, 192, 100, 1]}, {192, 
        Note[74, 192, 100, 1]}, {192, Note[53, 192, 50, 2]}, {192, 
        Note[77, 192, 50, 2]}, {384, Note[52, 192, 50, 1]}, {384, 
        Note[76, 192, 50, 1]}, {384, Note[55, 192, 100, 2]}, {384, 
        Note[79, 192, 100, 2]}}\)], "Output",
  CellLabel->"Out[33]="]
}, Open  ]],

Cell["\<\
This is the same example as above but the rule is applied only to Note events \
later than the first quarter. With simple /; conditions you can apply the \
rules to the subset of Events you want.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SortEventList[
      el /. {t_ /; t \[GreaterEqual] 192, 
            Note[n_, d_, v_, c_]} \[RuleDelayed] 
          Sequence[{t, Note[n - 12, d, v, c]}, {t, 
              Note[n + 12, d, v, c]}]]\)], "Input"],

Cell[BoxData[
    \({{0, TrackName["Sample Eventlist"]}, {0, Controller[10, 0, 1]}, {0, 
        Controller[10, 127, 2]}, {0, Note[60, 192, 50, 1]}, {0, 
        Note[64, 192, 100, 2]}, {192, Note[62, 192, 100, 1]}, {192, 
        Note[65, 192, 50, 2]}, {384, Note[52, 192, 50, 1]}, {384, 
        Note[76, 192, 50, 1]}, {384, Note[55, 192, 100, 2]}, {384, 
        Note[79, 192, 100, 2]}}\)], "Output"]
}, Open  ]],

Cell["\<\
You can even transform Events to any other primitive using rules. Here, for \
example, we translate notes to Circles according to their note number, time \
and velocity.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[
      Graphics[Cases[
            el, {_, _Note}] /. {t_, Note[n_, d_, v_, c_]} \[RuleDelayed] 
            Circle[{t, n*10}, v/10]], 
      AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[37]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .2104 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0473833 0.00235738 -1.39763 0.00235738 [
[ 0 0 0 0 ]
[ 1 .2104 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .2104 L
0 .2104 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
newpath
.04738 .0168 .01179 0 365.73 arc
s
newpath
.04738 .11109 .02357 0 365.73 arc
s
newpath
.5 .06394 .02357 0 365.73 arc
s
newpath
.5 .13467 .01179 0 365.73 arc
s
newpath
.95262 .11109 .01179 0 365.73 arc
s
newpath
.95262 .18181 .02357 0 365.73 arc
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[37]:=",
  ImageSize->{288, 60.5625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000?2000`400?l00000o`00003oo`3ooolQ
0?ooo`003`3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000=0?ooo`80000000<0oooo0000003o
ool0o`3oool?0?ooo`003@3oool01@000000oooo0?ooo`3oool000000?l0oooo3`3oool000`0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooo``0oooo000<0?ooo`030000003o
ool0oooo00<0oooo00=000000?ooo`3oool0o`3oool<0?ooo`00303oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0?l0oooo3@3oool000`0oooo0P0000030?ooo`030000003oool0oooo
0?l0oooo3@3oool000h0oooo0`00003o0?oooa00oooo003o0?ooob40oooo003o0?ooob40oooo002?
0?ooo`800000S`3oool008d0oooo0P0000020?ooo`800000S@3oool008/0oooo0P0000060?ooo`03
0000003oool0oooo08X0oooo002:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
R@3oool008T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`280?ooo`00R@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo08P0oooo00280?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0R03oool008P0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`270?ooo`00R@3oool00`000000oooo0?ooo`0:0?ooo`03@000003oool0oooo08L0oooo
00290?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0R03oool008T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`280?ooo`00RP3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo08T0oooo002:0?ooo`030000003oool0oooo00H0oooo0P00002;0?ooo`00
R`3oool3000000<0oooo0P00002=0?ooo`00303oool7000007/0oooo0`00002?0?ooo`002P3oool2
000000L0oooo00<000000?ooo`3oool0o`3oool;0?ooo`002@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo0?l0oooo2P3oool000T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`3g0?ooo`8000003`3oool000T0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`3e0?ooo`8000000P3oool2000000d0oooo00080?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0m03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo0008
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0l`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00/0oooo00080?ooo`030000003oool0oooo00/0oooo00=000000?oo
o`3oool0l`3oool00`000000oooo0?ooo`030?ooo`03@000003oool0oooo00/0oooo00090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0m@3oool01@000000oooo0?ooo`3oool00000
00h0oooo00090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0m@3oool01@000000
oooo0?ooo`3oool0000000h0oooo000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0N03oool2000007d0oooo0`00000?0?ooo`002P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo07H0oooo0P0000020?ooo`800000S@3oool000/0oooo0`0000040?ooo`800000N03o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08/0oooo000>0?ooo`@00000NP3oool0
0`000000oooo0?ooo`030?ooo`03@000003oool0oooo08/0oooo002=0?ooo`050000003oool0oooo
0?ooo`000000SP3oool008d0oooo00D000000?ooo`3oool0oooo0000002>0?ooo`00SP3oool30000
08l0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooo`h0oooo1P00000=
0?ooo`00o`3oool<0?ooo`8000001P3oool00`000000oooo0?ooo`0:0?ooo`00o`3oool;0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00?l0oooo2`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00P0oooo003o0?ooo`X0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`070?ooo`00o`3oool90?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool01`3oool00?l0oooo2@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00L0oooo003o0?ooo`T0oooo00<000000?ooo`3oool02`3oool00d000000oooo0?ooo`070?ooo`00
o`3oool:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00?l0oooo2P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo003o0?ooo`/0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`00o`3oool;0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool02@3oool00?l0oooo303oool3000000D0oooo00<000000?ooo`3o
ool02P3oool00?l0oooo3`3oool5000000d0oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {59.5625, 0}} -> {-23.0303, 592.874, 1.49847, \
1.49847}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[37]="]
}, Open  ]],

Cell["\<\
Of course you can even do the reverse action: tranform any other principle to \
MIDI Events using rules or other built-in functions. This is a slightly more \
complicated example.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SortEventList[
      MapIndexed[{\((#2[\([1]\)] - 1)\) quarter, 
            Note[#1, quarter, 100, 1]} &, 
        ToCharacterCode["\<You can even transform text to music!\>"]]]\)], \
"Input"],

Cell[BoxData[
    \({{0, Note[89, 192, 100, 1]}, {192, Note[111, 192, 100, 1]}, {384, 
        Note[117, 192, 100, 1]}, {576, Note[32, 192, 100, 1]}, {768, 
        Note[99, 192, 100, 1]}, {960, Note[97, 192, 100, 1]}, {1152, 
        Note[110, 192, 100, 1]}, {1344, Note[32, 192, 100, 1]}, {1536, 
        Note[101, 192, 100, 1]}, {1728, Note[118, 192, 100, 1]}, {1920, 
        Note[101, 192, 100, 1]}, {2112, Note[110, 192, 100, 1]}, {2304, 
        Note[32, 192, 100, 1]}, {2496, Note[116, 192, 100, 1]}, {2688, 
        Note[114, 192, 100, 1]}, {2880, Note[97, 192, 100, 1]}, {3072, 
        Note[110, 192, 100, 1]}, {3264, Note[115, 192, 100, 1]}, {3456, 
        Note[102, 192, 100, 1]}, {3648, Note[111, 192, 100, 1]}, {3840, 
        Note[114, 192, 100, 1]}, {4032, Note[109, 192, 100, 1]}, {4224, 
        Note[32, 192, 100, 1]}, {4416, Note[116, 192, 100, 1]}, {4608, 
        Note[101, 192, 100, 1]}, {4800, Note[120, 192, 100, 1]}, {4992, 
        Note[116, 192, 100, 1]}, {5184, Note[32, 192, 100, 1]}, {5376, 
        Note[116, 192, 100, 1]}, {5568, Note[111, 192, 100, 1]}, {5760, 
        Note[32, 192, 100, 1]}, {5952, Note[109, 192, 100, 1]}, {6144, 
        Note[117, 192, 100, 1]}, {6336, Note[115, 192, 100, 1]}, {6528, 
        Note[105, 192, 100, 1]}, {6720, Note[99, 192, 100, 1]}, {6912, 
        Note[33, 192, 100, 1]}}\)], "Output"]
}, Open  ]],

Cell["\<\
At this point you should have understood how you can use built-in functions \
in conjunction with Eventlists. The examples above do not in any way dictate \
the right way to do operations on Eventlists. Musica is designed to be an \
open system so you can do the same thing in many different ways.That is why \
common operations are done using built-in functions instead of dedicated \
ones. What you can do is only a matter of your programming skills and of \
course your imagination.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Defining new Events.", "Subsection"],

Cell[TextData[{
  "As you may have noticed all MIDI messages and Metaevents are represented \
in Musica in a function-like manner. However they are ",
  StyleBox["not",
    FontVariations->{"Underline"->True}],
  " functions, they are just heads. This means that if you try to evaluate a \
Note message for example, it will not be evaluated in any way. This design \
facilitates Eventlist manipulation as you have seen in the previous section. \
Internally Musica applies rules to transform this heads and finally export \
them to bytes. You can create your customized messages or Events by defining \
rules that transform them to the basic messages that ExportMIDI recognises. \
Applying these rules to your Eventlists will transform the new messages to \
the basic ones. Here we define a Chord Event."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ChordRule = {t_, Chord[notes_List, dur_, vel_, chan_]} \[RuleDelayed] 
        Sequence @@ Map[{t, Note[#, dur, vel, chan]} &, notes]\)], "Input"],

Cell[BoxData[
    \({t_, Chord[notes_List, dur_, vel_, chan_]} \[RuleDelayed] 
      Sequence @@ \(\(({t, Note[#1, dur, vel, chan]} &)\) /@ 
          notes\)\)], "Output"]
}, Open  ]],

Cell["\<\
Now here is an Eventlist containing Chord Events that is transformed to a \
regular Eventlist by applying ChordRule. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(chords = {{0, 
            Chord[{"\<C4\>", "\<E4\>", "\<G4\>"}, quarter, 100, 
              1]}, {quarter, 
            Chord[{"\<C4\>", "\<F4\>", "\<A4\>"}, quarter, 100, 1]}} /. 
        ChordRule\)], "Input"],

Cell[BoxData[
    \({{0, Note["C4", quarter, 100, 1]}, {0, 
        Note["E4", quarter, 100, 1]}, {0, 
        Note["G4", quarter, 100, 1]}, {quarter, 
        Note["C4", quarter, 100, 1]}, {quarter, 
        Note["F4", quarter, 100, 1]}, {quarter, 
        Note["A4", quarter, 100, 1]}}\)], "Output"]
}, Open  ]],

Cell["\<\
If you oftenly use custom events, you can use the CustomEvents option of \
ExportMIDI so that the appropriate rules are automatically applied before the \
file is exported. Here for example we make the ExportMIDI compatible with \
Chord Events.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetOptions[ExportMIDI, CustomEvents \[Rule] {ChordRule}]\)], "Input"],

Cell[BoxData[
    \({CustomEvents \[Rule] {{t_, 
              Chord[notes_List, dur_, vel_, chan_]} \[RuleDelayed] 
            Sequence @@ \(\(({t, Note[#1, dur, vel, chan]} &)\) /@ 
                notes\)}}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(ExportMIDI[{{0, 
          Chord[{"\<C4\>", "\<E4\>", "\<G4\>"}, quarter, 100, 1]}, {quarter, 
          Chord[{"\<C4\>", "\<F4\>", "\<A4\>"}, quarter, 100, 
            1]}}, "\<output.mid\>"]\)], "Input"],

Cell["\<\
Offcourse you can treat the new Events exactly like the basic ones.\
\>", "Text"],

Cell[BoxData[
    \(ExportMIDI[
      EventSequence[Chord[i + {48, 52, 55}, quarter, 100, 1], 
        quarter, {i, 0, 12}], "\<output.mid\>"]\)], "Input"],

Cell[TextData[{
  "The reverse procedure is also possible: take an Eventlist containing basic \
events and transform them to your customized Events. Here we take the last \
result and transform simultaneous Note Events to Chord Events. Notice that \
the rules are designed to be applied repeatedly. This rule works only with ",
  StyleBox["sorted",
    FontVariations->{"Underline"->True}],
  " Eventlists."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ReverseChordRules = {{before___, {t_, 
              Note[note1_, dur_, vel_, ch_]}, {t_, 
              Note[note2_, dur_, vel_, ch_]}, 
            after___} \[RuleDelayed] {before, {t, 
              Chord[{note1, note2}, dur, vel, ch]}, 
            after}, {before___, {t_, Chord[notes_, dur_, vel_, ch_]}, {t_, 
              Note[note2_, dur_, vel_, ch_]}, 
            after___} \[RuleDelayed] {before, {t, 
              Chord[Append[notes, note2], dur, vel, ch]}, after}}\)], "Input"],

Cell[BoxData[
    \({{before___, {t_, Note[note1_, dur_, vel_, ch_]}, {t_, 
            Note[note2_, dur_, vel_, ch_]}, 
          after___} \[RuleDelayed] {before, {t, 
            Chord[{note1, note2}, dur, vel, ch]}, 
          after}, {before___, {t_, Chord[notes_, dur_, vel_, ch_]}, {t_, 
            Note[note2_, dur_, vel_, ch_]}, 
          after___} \[RuleDelayed] {before, {t, 
            Chord[Append[notes, note2], dur, vel, ch]}, after}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(chords //. ReverseChordRules\)], "Input"],

Cell[BoxData[
    \({{0, Chord[{"C4", "E4", "G4"}, quarter, 100, 1]}, {quarter, 
        Chord[{"C4", "F4", "A4"}, quarter, 100, 1]}}\)], "Output"]
}, Open  ]],

Cell["\<\
Again, you can set the option ToCustomEvents of ImportMIDI so that \
simultaneous Notes in the same channel with the same duration and velocity \
are turned to Chord Events automatically after importing. ToCustomEvents \
rules are applied repeatedly.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetOptions[ImportMIDI, 
      ToCustomEvents \[Rule] ReverseChordRules]\)], "Input"],

Cell[BoxData[
    \({NoteConversion \[Rule] True, 
      ToCustomEvents \[Rule] {{before___, {t1_, 
                  Note[note1_, dur1_, vel1_, ch1_]}, {t2_, 
                  Note[note2_, dur2_, vel2_, ch2_]}, after___} /; 
              t1 == t2 && dur1 == dur2 && vel1 == vel2 && 
                ch1 == ch2 \[RuleDelayed] {before, {t1, 
                Chord[{note1, note2}, dur1, vel1, ch1]}, 
              after}, {before___, {t1_, 
                  Chord[notes_, dur1_, vel1_, ch1_]}, {t2_, 
                  Note[note2_, dur2_, vel2_, ch2_]}, after___} /; 
              t1 == t2 && dur1 == dur2 && vel1 == vel2 && 
                ch1 == ch2 \[RuleDelayed] {before, {t1, 
                Chord[Append[notes, note2], dur1, vel1, ch1]}, after}}, 
      FinalFunction \[Rule] Identity}\)], "Output"]
}, Open  ]],

Cell["\<\
Sometimes, it is difficult to convert a set of Events in an Eventlist to a \
custom event by just applying a repeated rule. Most of the times it is more \
efficient to define a function that will do the job. For example \
ReverseChordRules are quite easy to express, but can take a considerable \
amount of time when applied to big Eventlists. You can write an optimized \
function that does the same job but reduces execution time. If you want such \
a function to be automatically applied to your imported files use the \
FinalFunction option of ImportMIDI. In fact there is such a function that is \
applied by default every time you import a MIDI file. This function \
transforms pairs of NoteOn and NoteOff (or NoteOn with 0 velocity) events to \
the more convenient Note Event that has a duration argument. If you don't \
want this conversion to be done you can set the NoteConversion option of \
ImportMIDI to False.\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Section"],

Cell[TextData[{
  "In this section you will find some applications of Musica. They are \
selected to demonstrate its power and ease while at the same time giving you \
ideas of how ",
  StyleBox["you",
    FontVariations->{"Underline"->True}],
  " can take advantage of it. I will gladly add your examples in this section \
if you think that you have found something that might interest other users of \
",
  StyleBox["Musica",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell["Algorithmic Music", "Subsection"],

Cell[TextData[{
  "Algorithmic Music has always been a subject of experts. Well, it is now \
easy to create music from ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " algorithms. What remains difficult though, is to create algorithmic music \
that actually sounds good."
}], "Text"],

Cell[CellGroupData[{

Cell["Music from numbers", "Subsubsection"],

Cell["\<\
You can use the digits of numbers in any base to create Note Events. Here for \
example we use the digits of \[Pi] as Note numbers and durations of Note \
Events. Divine music? Well, it sounds awful to me...\
\>", "Text"],

Cell[BoxData[{
    \(\(PiDigits = \(RealDigits[Pi, 12, 
            100]\)[\([1]\)];\)\), "\[IndentingNewLine]", 
    \(ExportMIDI[
      EventSequence[
        Note[PiDigits[\([2  i - 1]\)] + 60, \((PiDigits[\([2  i]\)] + 1)\) 
            thirtysecond, 100, 1], \((PiDigits[\([2  i]\)] + 1)\) 
          thirtysecond, {i, 1, 50}], "\<output.mid\>"]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Music from functions", "Subsubsection"],

Cell[TextData[{
  "Any ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function can be used as a Note argument provided it returns an Integer \
that is in the legal range. Built-in Round and Mod functions can be used to \
tailor any function for use as a Note argument.  Here we use Prime as Note \
number and duration. Mod is used to keep Prime into legal range. The first 10 \
notes are somehow melodic."
}], "Text"],

Cell[BoxData[
    \(ExportMIDI[
      EventSequence[
        Note[Mod[Prime[i], 13] + 60, 
          2^\((Mod[Prime[i - 100], 3] + 1)\) thirtysecond, 100, 1], 
        2^\((Mod[Prime[i - 100], 3] + 1)\) thirtysecond, {i, 146, 
          200}], "\<output.mid\>"]\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Sound Design", "Subsection"],

Cell["\<\
Musica can be used to create complex sequences of Events that would take ages \
to construct with a sequencer.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Sound Effects", "Subsubsection"],

Cell["\<\
Musica excells in the creation of Sound Effects. Here are a few simple \
examples. Use different programs (patches) of your synth to get different \
results. \
\>", "Text"],

Cell["Here are all MIDI notes in ultra-fast succesion.", "Text"],

Cell[BoxData[
    \(ExportMIDI[
      EventSequence[Note[i, 1, 100, 1], 
        1, {i, 0, 127}], "\<output.mid\>"]\)], "Input"],

Cell["\<\
Another variation adding some quick ups and downs with the Sin function. \
\>", "Text"],

Cell[BoxData[
    \(ExportMIDI[
      EventSequence[Note[i + Round[4\ \ Sin[i]], 20, 100, 1], 
        10, {i, 0, 100}], "\<output.mid\>"]\)], "Input"],

Cell["\<\
Random Note generation. Resembles sample & hold. Use a sinewave patch to get \
a computer sci-fi effect.\
\>", "Text"],

Cell[BoxData[
    \(ExportMIDI[
      EventSequence[Note[Random[Integer, 127], 20, 100, 1], 
        10, {i, 0, 50}], "\<output.mid\>"]\)], "Input"],

Cell["\<\
A single note with random cutoff changes (requires a synth with a filter). \
Use a sustained patch.\
\>", "Text"],

Cell[BoxData[
    \(ExportMIDI[
      Join[\[IndentingNewLine]{{0, 
            Note[60, 500, 100, 1]}}, \[IndentingNewLine]EventSequence[
          Controller[74, Random[Integer, 127], 1], 
          10, \[IndentingNewLine]{i, 0, 50}]], "\<output.mid\>"]\)], "Input"],

Cell["\<\
Here are four Note sequences that form sine waves with different phases. Use \
fx patches to get interesting effects.\
\>", "Text"],

Cell[BoxData[
    \(ExportMIDI[
      Join @@ Table[
          EventSequence[
            Note[Round[63\ Sin[j\ Pi/2 + 2  Pi\ i/100]] + 64, 10, 100, 1], 
            10, {i, 0, 100}], {j, 0, 3}], "\<output.mid\>"]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["LFOs and Envelopes", "Subsubsection"],

Cell["\<\
Most synths have simple Low Frequency Oscillators with about 3-6 different \
waveforms. With Musica you can add LFOs of any complexity  that control the \
values of any MIDI message. Similarly you can create complex envelopes for \
any MIDI message that are far more complex than the usual ADSR envelopes used \
in most synths.\
\>", "Text"],

Cell["\<\
Low frequency oscilators can be created using any periodic function. Of \
course the LFO can control any MIDI message, but PitchBend and Controller are \
the most common. This is an example using PitchBend and Sin[2 Pi Cos[x]] as a \
fuction. Again, use a sustained patch.\
\>", "Text"],

Cell[BoxData[
    \(ExportMIDI[
      Join[\[IndentingNewLine]{{0, 
            Note[60, 500, 100, 1]}}, \[IndentingNewLine]EventSequence[
          PitchBend[Round[8191\ Sin[2  Pi\ Cos[2  Pi\ i/250]]], 1], 
          1, \[IndentingNewLine]{i, 0, 500}]], "\<output.mid\>"]\)], "Input"],

Cell["\<\
Use Interpolation (or any of the fitting functions found in Numerical Math \
packages like SplineFit) to create envelopes of any complexity with any MIDI \
message. This is a linear filter cutoff envelope.\
\>", "Text"],

Cell[BoxData[
    \(ExportMIDI[
      Join[\[IndentingNewLine]{{1, 
            Note[60, 500, 100, 1]}}, \[IndentingNewLine]EventSequence[
          Controller[74, 
            Round[\(Interpolation[{{0, 0}, {5, 127}, {20, 50}, {60, 50}, {90, 
                      127}, {100, 0}}, InterpolationOrder \[Rule] 1]\)[i]], 
            1], 5, \[IndentingNewLine]{i, 0, 
            100}]], "\<output.mid\>"]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Templates", "Subsubsection"],

Cell["\<\
You can construct templates to play or record over in your sequencer. This is \
an example featuring two sine LFOs one for pan and one for cutoff.\
\>", "Text"],

Cell[BoxData[
    \(ExportMIDI[
      Join[EventSequence[
          Controller[10, Round[63\ Sin[2  Pi\ i/100]] + 64, 1], 
          10, {i, 0, 500}], 
        EventSequence[Controller[74, Round[63\ Sin[2  Pi\ i/100]] + 64, 1], 
          10, {i, 0, 500}]], "\<output.mid\>"]\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Editing", "Subsection"],

Cell["Musica can be used to edit your sequences.", "Text"],

Cell[CellGroupData[{

Cell["Advanced MIDI file manipulation", "Subsubsection"],

Cell["\<\
You can manipulate any MIDI file with the flexibility of a programming \
language.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(l = ImportMIDI["\<Entertainer.mid\>"];\)\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Format: "\[InvisibleSpace]0\),
      SequenceForm[ "Format: ", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Tracks: "\[InvisibleSpace]1\),
      SequenceForm[ "Tracks: ", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("PPQ: "\[InvisibleSpace]192\),
      SequenceForm[ "PPQ: ", 192],
      Editable->False]], "Print"]
}, Open  ]],

Cell["\<\
Let us add a small accidental before every note higher than C5. This makes \
the song sound funny.\
\>", "Text"],

Cell[BoxData[
    \(ExportMIDI[
      l /. {t_, Note[n_ /; n \[GreaterEqual] 60, d_, v_, 1]} \[RuleDelayed] 
          Sequence[{t, Note[n - 1, 3, v, 1]}, {t + 3, 
              Note[n, d - 3, v, 1]}], "\<output.mid\>"]\)], "Input"],

Cell["\<\
Inverting the keyboard makes this happy ragtime sound like Bach. Not bad...\
\>", "Text"],

Cell[BoxData[
    \(ExportMIDI[
      l /. Note[n_, d_, v_, c_] \[Rule] 
          Note[127 - n, d, v, c]\ , "\<output.mid\>"]\)], "Input"],

Cell["\<\
Here we add some random alterations to the time of Note events, this effect \
is known as \"Humanisation\" in some sequencers. By changing the range of the \
Random function we can control the amount of the effect. With the range set \
at {-10,10} it seems like some clumsy pianist playing.\
\>", "Text"],

Cell[BoxData[
    \(ExportMIDI[
      l /. {t_, 
            Note[n_, d_, v_, c_]} :> {Abs[
              t + Random[Integer, {\(-10\), 10}]], 
            Note[n, d, v, c]}\ , "\<output.mid\>"]\)], "Input"],

Cell["\<\
The opposite effect is present in all major sequencers and called \
\"Quantisation\". Here we define a simple rule that fixes both the start \
times and the durations of Note events. More advanced quantisation algorithms \
can be easily programmed based on the built in Round function.\
\>", "Text"],

Cell[BoxData[
    \(Quantize[res_, 
        PPQ_:  192] := {t_, 
          Note[n_, d_, v_, 
            c_]} \[RuleDelayed] {res\ Round[t/\((res /. Durations[PPQ])\)], 
          Note[n, res\ Ceiling[d/\((res /. Durations[PPQ])\)], v, 
            c]}\)], "Input"],

Cell["\<\
We import the last humanized file and bring it back to normal by quantizing \
it.\
\>", "Text"],

Cell[BoxData[
    \(\(\(ExportMIDI[
      ImportMIDI["\<output.mid\>"] /. 
        Quantize[
          sixteenth], "\<output.mid\>"]\)\(\[IndentingNewLine]\)\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["MIDI Effects", "Subsubsection"],

Cell["\<\
You can create your own MIDI effects. These can be implemented as rules or \
functions that modify an existing Eventlist.\
\>", "Text"],

Cell["\<\
Here is a simple MIDI echo effect that is implemented as a rule.\
\>", "Text"],

Cell[BoxData[
    \(Echo[delay_, repeats_] := {t_, Note[n_, d_, v_, c_]} \[Rule] 
        Sequence @@ 
          Table[{t + i\ delay, Note[n, d, Round[v/\((i + 1)\)], c]}, {i, 0, 
              repeats}]\)], "Input"],

Cell["Now lets apply it to a simple Eventlist and sort the result.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SortEventList[{{0, Note[60, quarter, 100, 1]}, {quarter, 
            Note[72, quarter, 100, 1]}} /. Echo[quarter, 3]]\)], "Input"],

Cell[BoxData[
    \({{0, Note[60, 192, 100, 1]}, {192, Note[60, 192, 50, 1]}, {192, 
        Note[72, 192, 100, 1]}, {384, Note[60, 192, 33, 1]}, {384, 
        Note[72, 192, 50, 1]}, {576, Note[60, 192, 25, 1]}, {576, 
        Note[72, 192, 33, 1]}, {768, Note[72, 192, 25, 1]}}\)], "Output"]
}, Open  ]],

Cell["\<\
Any effect is possible. The most interesting midi effects are those that \
can't be duplicated with an audio effects processor. Use your imagination to \
create new effects. Here is the same echo but each time a note is repeated it \
is lowered by an octave.\
\>", "Text"],

Cell[BoxData[
    \(EchoOctave[delay_, repeats_] := {t_, Note[n_, d_, v_, c_]} \[Rule] 
        Sequence @@ 
          Table[{t + i\ delay, 
              Note[n - 12  i, d, Round[v/\((i + 1)\)], c]}, {i, 0, 
              repeats}]\)], "Input"],

Cell["\<\
The next effect takes a Note and transforms it to many smaller Notes of \
duration defined in rate. The idea came from Mike Oldfields: The Bell (from \
the Tubular Bells II album) where the anouncer says:\"The Venician Effect\" \
and something like this effect follows. It works well with dulcimer or santur \
patches. Notice the use of the function Durations. Durations[PPQ] is a set of \
rules that transform musical durations like quarter or sixteenthtriplet to \
their corresponding number of ticks according to the PPQ. This function is \
useful when you have to convert durations before using SortEventlist or \
ExportMIDI. In this example we have to use Durations so that Floor[d/rate-.1] \
gives a numerical result immediatelly for use as an upper limit of Table.\
\>", "Text"],

Cell[BoxData[
    \(Venician[rate_, 
        PPQ_:  192] := {t_, Note[n_, d_, v_, c_]} \[RuleDelayed] 
        Module[{num}, num = Floor[\(- .1\) + d/rate /. Durations[PPQ]]; 
          Sequence @@ 
            Table[{t + i\ rate, Note[n, rate, v, c]}, {i, 0, 
                num}]]\)], "Input"],

Cell["\<\
The single Note of the sample Eventlist is turned to many smaller Notes each \
with thirtysecond duration.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({{0, Note[60, whole, 100, 1]}} /. Venician[thirtysecond]\)], "Input"],

Cell[BoxData[
    \({{0, Note[60, thirtysecond, 100, 1]}, {thirtysecond, 
        Note[60, thirtysecond, 100, 1]}, {2\ thirtysecond, 
        Note[60, thirtysecond, 100, 1]}, {3\ thirtysecond, 
        Note[60, thirtysecond, 100, 1]}, {4\ thirtysecond, 
        Note[60, thirtysecond, 100, 1]}, {5\ thirtysecond, 
        Note[60, thirtysecond, 100, 1]}, {6\ thirtysecond, 
        Note[60, thirtysecond, 100, 1]}, {7\ thirtysecond, 
        Note[60, thirtysecond, 100, 1]}, {8\ thirtysecond, 
        Note[60, thirtysecond, 100, 1]}, {9\ thirtysecond, 
        Note[60, thirtysecond, 100, 1]}, {10\ thirtysecond, 
        Note[60, thirtysecond, 100, 1]}, {11\ thirtysecond, 
        Note[60, thirtysecond, 100, 1]}, {12\ thirtysecond, 
        Note[60, thirtysecond, 100, 1]}, {13\ thirtysecond, 
        Note[60, thirtysecond, 100, 1]}, {14\ thirtysecond, 
        Note[60, thirtysecond, 100, 1]}, {15\ thirtysecond, 
        Note[60, thirtysecond, 100, 1]}, {16\ thirtysecond, 
        Note[60, thirtysecond, 100, 1]}, {17\ thirtysecond, 
        Note[60, thirtysecond, 100, 1]}, {18\ thirtysecond, 
        Note[60, thirtysecond, 100, 1]}, {19\ thirtysecond, 
        Note[60, thirtysecond, 100, 1]}, {20\ thirtysecond, 
        Note[60, thirtysecond, 100, 1]}, {21\ thirtysecond, 
        Note[60, thirtysecond, 100, 1]}, {22\ thirtysecond, 
        Note[60, thirtysecond, 100, 1]}, {23\ thirtysecond, 
        Note[60, thirtysecond, 100, 1]}, {24\ thirtysecond, 
        Note[60, thirtysecond, 100, 1]}, {25\ thirtysecond, 
        Note[60, thirtysecond, 100, 1]}, {26\ thirtysecond, 
        Note[60, thirtysecond, 100, 1]}, {27\ thirtysecond, 
        Note[60, thirtysecond, 100, 1]}, {28\ thirtysecond, 
        Note[60, thirtysecond, 100, 1]}, {29\ thirtysecond, 
        Note[60, thirtysecond, 100, 1]}, {30\ thirtysecond, 
        Note[60, thirtysecond, 100, 1]}, {31\ thirtysecond, 
        Note[60, thirtysecond, 100, 1]}}\)], "Output"]
}, Closed]],

Cell["\<\
The next effect is a MIDI compressor. Its function is similar to that of \
audio signal compressors but instead of compressing audio levels it \
compresses note velocities. This is sometimes needed because in modern \
synths, velocity alters some aspects of the produced sound other than volume \
(such as filter cutoff). While an audio compressor would only compress the \
volume of the sound, its MIDI equivalent would evenly reduce the other \
aspects as well. In sample based synths there are patches that use different \
samples according to note velocity, for example you can have a slap bass \
patch where slapping occurs only after a certain velocity threshold. In such \
patches MIDI compression gives completely different results than audio \
compression. Applying similar dynamic effects is like changing the velocity \
curve of your synth, an option that most modern synths offer. \
\>", "Text"],

Cell["\<\
This simple MIDI compressor can also be used as an expander (ratio > 1) or a \
limiter (ratio = 0). If your Sequencer can plot a graph of the velocities \
observe the exported file to see the effect. If you replace the simple linear \
function used with more complex functions you can process the whole dynamic \
range with unprecedent power.\
\>", "Text"],

Cell[BoxData[
    \(Compressor[ratio_, threshold_Integer] := 
      Note[n_, d_, v_, c_] \[RuleDelayed] 
        Note[n, d, 
          If[v > threshold, 
            Min[Round[\((v - threshold)\)\ ratio + threshold], 127], v], 
          c]\)], "Input"],

Cell[BoxData[
    \(ExportMIDI[
      EventSequence[Note["\<C4\>", sixteenth, i, 1], sixteenth, {i, 1, 127}] /. 
        Compressor[ .4, 60], "\<output.mid\>"]\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Analysis", "Subsection"],

Cell[TextData[{
  "You can analyze MIDI data and therefore their musical content using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s vast function inventory. \nHere we plot the frequency for each note in \
an event list  (0-11 corresponds to C-B)"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(l = ImportMIDI["\<Entertainer.mid\>"];\)\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Format: "\[InvisibleSpace]0\),
      SequenceForm[ "Format: ", 0],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Tracks: "\[InvisibleSpace]1\),
      SequenceForm[ "Tracks: ", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("PPQ: "\[InvisibleSpace]192\),
      SequenceForm[ "PPQ: ", 192],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Histogram[
      Cases[l, {_, Note[n_, _, _, _]} \[Rule] Mod[n, 12]]]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0869565 0.0147151 0.00676556 [
[.17391 .00222 -6 -9 ]
[.17391 .00222 6 0 ]
[.34783 .00222 -6 -9 ]
[.34783 .00222 6 0 ]
[.52174 .00222 -6 -9 ]
[.52174 .00222 6 0 ]
[.69565 .00222 -6 -9 ]
[.69565 .00222 6 0 ]
[.86957 .00222 -9 -9 ]
[.86957 .00222 9 0 ]
[-0.0125 .15003 -12 -4.5 ]
[-0.0125 .15003 0 4.5 ]
[-0.0125 .28534 -12 -4.5 ]
[-0.0125 .28534 0 4.5 ]
[-0.0125 .42065 -12 -4.5 ]
[-0.0125 .42065 0 4.5 ]
[-0.0125 .55596 -12 -4.5 ]
[-0.0125 .55596 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17391 .01472 m
.17391 .02097 L
s
[(2.)] .17391 .00222 0 1 Mshowa
.34783 .01472 m
.34783 .02097 L
s
[(4.)] .34783 .00222 0 1 Mshowa
.52174 .01472 m
.52174 .02097 L
s
[(6.)] .52174 .00222 0 1 Mshowa
.69565 .01472 m
.69565 .02097 L
s
[(8.)] .69565 .00222 0 1 Mshowa
.86957 .01472 m
.86957 .02097 L
s
[(10.)] .86957 .00222 0 1 Mshowa
0 .01472 m
1 .01472 L
s
0 .15003 m
.00625 .15003 L
s
[(20)] -0.0125 .15003 1 0 Mshowa
0 .28534 m
.00625 .28534 L
s
[(40)] -0.0125 .28534 1 0 Mshowa
0 .42065 m
.00625 .42065 L
s
[(60)] -0.0125 .42065 1 0 Mshowa
0 .55596 m
.00625 .55596 L
s
[(80)] -0.0125 .55596 1 0 Mshowa
.125 Mabswid
0 .04854 m
.00375 .04854 L
s
0 .08237 m
.00375 .08237 L
s
0 .1162 m
.00375 .1162 L
s
0 .18385 m
.00375 .18385 L
s
0 .21768 m
.00375 .21768 L
s
0 .25151 m
.00375 .25151 L
s
0 .31917 m
.00375 .31917 L
s
0 .35299 m
.00375 .35299 L
s
0 .38682 m
.00375 .38682 L
s
0 .45448 m
.00375 .45448 L
s
0 .4883 m
.00375 .4883 L
s
0 .52213 m
.00375 .52213 L
s
0 .58979 m
.00375 .58979 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
0 .01472 m
0 .60332 L
.04348 .60332 L
.04348 .01472 L
F
0 g
.5 Mabswid
0 .01472 m
0 .60332 L
.04348 .60332 L
.04348 .01472 L
0 .01472 L
s
1 0 0 r
.04348 .01472 m
.04348 .01472 L
.08696 .01472 L
.08696 .01472 L
F
0 g
.04348 .01472 m
.04348 .01472 L
.08696 .01472 L
.08696 .01472 L
.04348 .01472 L
s
1 0 0 r
.08696 .01472 m
.08696 .01472 L
.13043 .01472 L
.13043 .01472 L
F
0 g
.08696 .01472 m
.08696 .01472 L
.13043 .01472 L
.13043 .01472 L
.08696 .01472 L
s
1 0 0 r
.13043 .01472 m
.13043 .01472 L
.17391 .01472 L
.17391 .01472 L
F
0 g
.13043 .01472 m
.13043 .01472 L
.17391 .01472 L
.17391 .01472 L
.13043 .01472 L
s
1 0 0 r
.17391 .01472 m
.17391 .32593 L
.21739 .32593 L
.21739 .01472 L
F
0 g
.17391 .01472 m
.17391 .32593 L
.21739 .32593 L
.21739 .01472 L
.17391 .01472 L
s
1 0 0 r
.21739 .01472 m
.21739 .01472 L
.26087 .01472 L
.26087 .01472 L
F
0 g
.21739 .01472 m
.21739 .01472 L
.26087 .01472 L
.26087 .01472 L
.21739 .01472 L
s
1 0 0 r
.26087 .01472 m
.26087 .07561 L
.30435 .07561 L
.30435 .01472 L
F
0 g
.26087 .01472 m
.26087 .07561 L
.30435 .07561 L
.30435 .01472 L
.26087 .01472 L
s
1 0 0 r
.30435 .01472 m
.30435 .01472 L
.34783 .01472 L
.34783 .01472 L
F
0 g
.30435 .01472 m
.30435 .01472 L
.34783 .01472 L
.34783 .01472 L
.30435 .01472 L
s
1 0 0 r
.34783 .01472 m
.34783 .44771 L
.3913 .44771 L
.3913 .01472 L
F
0 g
.34783 .01472 m
.34783 .44771 L
.3913 .44771 L
.3913 .01472 L
.34783 .01472 L
s
1 0 0 r
.3913 .01472 m
.3913 .01472 L
.43478 .01472 L
.43478 .01472 L
F
0 g
.3913 .01472 m
.3913 .01472 L
.43478 .01472 L
.43478 .01472 L
.3913 .01472 L
s
1 0 0 r
.43478 .01472 m
.43478 .14326 L
.47826 .14326 L
.47826 .01472 L
F
0 g
.43478 .01472 m
.43478 .14326 L
.47826 .14326 L
.47826 .01472 L
.43478 .01472 L
s
1 0 0 r
.47826 .01472 m
.47826 .01472 L
.52174 .01472 L
.52174 .01472 L
F
0 g
.47826 .01472 m
.47826 .01472 L
.52174 .01472 L
.52174 .01472 L
.47826 .01472 L
s
1 0 0 r
.52174 .01472 m
.52174 .05531 L
.56522 .05531 L
.56522 .01472 L
F
0 g
.52174 .01472 m
.52174 .05531 L
.56522 .05531 L
.56522 .01472 L
.52174 .01472 L
s
1 0 0 r
.56522 .01472 m
.56522 .01472 L
.6087 .01472 L
.6087 .01472 L
F
0 g
.56522 .01472 m
.56522 .01472 L
.6087 .01472 L
.6087 .01472 L
.56522 .01472 L
s
1 0 0 r
.6087 .01472 m
.6087 .40712 L
.65217 .40712 L
.65217 .01472 L
F
0 g
.6087 .01472 m
.6087 .40712 L
.65217 .40712 L
.65217 .01472 L
.6087 .01472 L
s
1 0 0 r
.65217 .01472 m
.65217 .01472 L
.69565 .01472 L
.69565 .01472 L
F
0 g
.65217 .01472 m
.65217 .01472 L
.69565 .01472 L
.69565 .01472 L
.65217 .01472 L
s
1 0 0 r
.69565 .01472 m
.69565 .04854 L
.73913 .04854 L
.73913 .01472 L
F
0 g
.69565 .01472 m
.69565 .04854 L
.73913 .04854 L
.73913 .01472 L
.69565 .01472 L
s
1 0 0 r
.73913 .01472 m
.73913 .01472 L
.78261 .01472 L
.78261 .01472 L
F
0 g
.73913 .01472 m
.73913 .01472 L
.78261 .01472 L
.78261 .01472 L
.73913 .01472 L
s
1 0 0 r
.78261 .01472 m
.78261 .17709 L
.82609 .17709 L
.82609 .01472 L
F
0 g
.78261 .01472 m
.78261 .17709 L
.82609 .17709 L
.82609 .01472 L
.78261 .01472 L
s
1 0 0 r
.82609 .01472 m
.82609 .01472 L
.86957 .01472 L
.86957 .01472 L
F
0 g
.82609 .01472 m
.82609 .01472 L
.86957 .01472 L
.86957 .01472 L
.82609 .01472 L
s
1 0 0 r
.86957 .01472 m
.86957 .04854 L
.91304 .04854 L
.91304 .01472 L
F
0 g
.86957 .01472 m
.86957 .04854 L
.91304 .04854 L
.91304 .01472 L
.86957 .01472 L
s
1 0 0 r
.91304 .01472 m
.91304 .01472 L
.95652 .01472 L
.95652 .01472 L
F
0 g
.91304 .01472 m
.91304 .01472 L
.95652 .01472 L
.95652 .01472 L
.91304 .01472 L
s
1 0 0 r
.95652 .01472 m
.95652 .15679 L
1 .15679 L
1 .01472 L
F
0 g
.95652 .01472 m
.95652 .15679 L
1 .15679 L
1 .01472 L
.95652 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oofmk8Fmk000iKg/4
0003Kg/2000XKg/30002Kg/2000WKg/30004Kg/2000WKg/20004Kg/2000SKg/50002Kg/20004Kg/2
000NKg/003U_N`03001_Nfmk02m_N`03001_Nfmk02Y_N`04001_Nfmk000[Kg/01000Kg]_N`00:Vmk
00D006mkKg]_N`00009_N`03001_Nfmk025_N`00>Vmk00<006mkKg/0:fmk1@00:fmk00@006mkKg/0
02]_N`04001_Nfmk000ZKg/01@00Kg]_Nfmk00000Vmk00<006mkKg/08Fmk000kKg/00`00Kg]_N`0Z
Kg/01000Kg]_N`00;6mk0`00;Fmk0P00:fmk00D006mkKg]_N`00009_N`03001_Nfmk025_N`00>Fmk
00@006mkKg/002a_N`03001_N`0002e_N`03001_Nfmk02]_N`04001_Nfmk000ZKg/01@00Kg]_Nfmk
00000Vmk00<006mkKg/08Fmk000jKg/2000^Kg/2000]Kg/3000/Kg/2000ZKg/20004Kg/2000TKg/0
0?m_Nb5_N`003fmk00<006mkKg/0ofmk3fmk000?Kg/00`00Kg]_N`3oKg/?Kg/000m_N`03001_Nfmk
0?m_N`m_N`003fmk00<006mkKg/0ofmk3fmk000?Kg_o000B000000m_N`03001l07`000Ul0003001_
Nfmk021_N`03001l07`000Ul0003001_Nfmk00U_N`03001l07`000Ul0003001_Nfmk00Q_N`03001l
07`000Ul0003001_Nfmk00U_N`03001l07`000Ul0003001_Nfmk00U_N`03001l07`000Ql0003001_
Nfmk00U_N`03001l07`000Ul0003001_Nfmk00U_N`03001l07`000Ul0003001_Nfmk00Q_N`03001l
07`000Ul0003001_Nfmk00U_N`03001l07`000Ul0003001_Nfmk00U_N`03001l07`000Ul00400000
3fmk00<007`0O0002G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/02Fmk00<007`0O000
2G`000<006mkKg/026mk00<007`0O0002G`000<006mkKg/02Fmk00<007`0O0002G`000<006mkKg/0
2Fmk00<007`0O00027`000<006mkKg/02Fmk00<007`0O0002G`000<006mkKg/02Fmk00<007`0O000
2G`000<006mkKg/026mk00<007`0O0002G`000<006mkKg/02Fmk00<007`0O0002G`000<006mkKg/0
2Fmk00<007`0O0002G`00@00000?Kg/00`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l0009O000
0`00Kg]_N`09Kg/00`00O01l0009O0000`00Kg]_N`08Kg/00`00O01l0009O0000`00Kg]_N`09Kg/0
0`00O01l0009O0000`00Kg]_N`09Kg/00`00O01l0008O0000`00Kg]_N`09Kg/00`00O01l0009O000
0`00Kg]_N`09Kg/00`00O01l0009O0000`00Kg]_N`08Kg/00`00O01l0009O0000`00Kg]_N`09Kg/0
0`00O01l0009O0000`00Kg]_N`09Kg/00`00O01l0009O001000000m_N`03001l07`000Ul0003001_
Nfmk021_N`03001l07`000Ul0003001_Nfmk00U_N`03001l07`000Ul0003001_Nfmk00Q_N`03001l
07`000Ul0003001_Nfmk00U_N`03001l07`000Ul0003001_Nfmk00U_N`03001l07`000Ql0003001_
Nfmk00U_N`03001l07`000Ul0003001_Nfmk00U_N`03001l07`000Ul0003001_Nfmk00Q_N`03001l
07`000Ul0003001_Nfmk00U_N`03001l07`000Ul0003001_Nfmk00U_N`03001l07`000Ul00400000
3fmk00<007`0O0002G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/02Fmk00<007`0O000
2G`000<006mkKg/026mk00<007`0O0002G`000<006mkKg/02Fmk00<007`0O0002G`000<006mkKg/0
2Fmk00<007`0O00027`000<006mkKg/02Fmk00<007`0O0002G`000<006mkKg/02Fmk00<007`0O000
2G`000<006mkKg/026mk00<007`0O0002G`000<006mkKg/02Fmk00<007`0O0002G`000<006mkKg/0
2Fmk00<007`0O0002G`00@00000?Kg/00`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l0009O000
0`00Kg]_N`09Kg/00`00O01l0009O0000`00Kg]_N`08Kg/00`00O01l0009O0000`00Kg]_N`09Kg/0
0`00O01l0009O0000`00Kg]_N`09Kg/00`00O01l0008O0000`00Kg]_N`09Kg/00`00O01l0009O000
0`00Kg]_N`09Kg/00`00O01l0009O0000`00Kg]_N`08Kg/00`00O01l0009O0000`00Kg]_N`09Kg/0
0`00O01l0009O0000`00Kg]_N`09Kg/00`00O01l0009O001000000m_N`03001l07`000Ul0003001_
Nfmk021_N`03001l07`000Ul0003001_Nfmk00U_N`03001l07`000Ul0003001_Nfmk00Q_N`03001l
07`000Ul0003001_Nfmk00U_N`03001l07`000Ul0003001_Nfmk00U_N`03001l07`000Ql0003001_
Nfmk00U_N`03001l07`000Ul0003001_Nfmk00U_N`03001l07`000Ul0003001_Nfmk00Q_N`03001l
07`000Ul0003001_Nfmk00U_N`03001l07`000Ul0003001_Nfmk00U_N`03001l07`000Ul00400000
3fmk00<007`0O0002G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/02Fmk00<007`0O000
2G`000<006mkKg/026mk00<007`0O0002G`000<006mkKg/02Fmk00<007`0O0002G`000<006mkKg/0
2Fmk00<007`0O00027`000<006mkKg/02Fmk00<007`0O0002G`000<006mkKg/02Fmk00<007`0O000
2G`000<006mkKg/026mk00<007`0O0002G`000<006mkKg/02Fmk00<007`0O0002G`000<006mkKg/0
2Fmk00<007`0O0002G`00@00000?Kg/00`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l0009O000
0`00Kg]_N`09Kg/00`00O01l0009O0000`00Kg]_N`08Kg/00`00O01l0009O0000`00Kg]_N`09Kg/0
0`00O01l0009O0000`00Kg]_N`09Kg/00`00O01l0008O0000`00Kg]_N`09Kg/00`00O01l0009O000
0`00Kg]_N`09Kg/=000:Kg/00`00O01l0009O0000`00Kg]_N`09Kg/=000;Kg/00`00O01l0009O001
000000m_N`03001l07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003001_Nfmk00U_N`03001l
07`000Ul0003001_Nfmk00Q_N`03001l07`000Ul0003001_Nfmk00U_N`03001l07`000Ul0003001_
Nfmk00U_N`03001l07`000Ql0003001_Nfmk00U_N`03001l07`000Ul0003001_Nfmk021_N`03001l
07`000Ul0003001_Nfmk025_N`03001l07`000Ul004000003fmk00<007`0O0002G`000<006mkKg/0
86mk00<007`0O0002G`000<006mkKg/02Fmk00<007`0O0002G`000<006mkKg/026mk00<007`0O000
2G`000<006mkKg/02Fmk00<007`0O0002G`000<006mkKg/02Fmk30002fmk00<007`0O0002G`000<0
06mkKg/086mk00<007`0O0002G`000<006mkKg/08Fmk00<007`0O0002G`00@00000?Kg/00`00O01l
0009O0000`00Kg]_N`0PKg/00`00O01l0009O0000`00Kg]_N`09Kg/00`00O01l0009O0000`00Kg]_
N`08Kg/00`00O01l0009O0000`00Kg]_N`09Kg/00`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l
0009O0000`00Kg]_N`0PKg/00`00O01l0009O0000`00Kg]_N`0QKg/00`00O01l0009O001000000m_
N`03001l07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003001_Nfmk00U_N`03001l07`000Ul
0003001_Nfmk00Q_N`03001l07`000Ul0003001_Nfmk00U_N`03001l07`000Ul0003001_Nfmk021_
N`03001l07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003001_Nfmk025_N`03001l07`000Ul
004000003fmk00<007`0O0002G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/02Fmk00<0
07`0O0002G`000<006mkKg/026mk00<007`0O0002G`000<006mkKg/02Fmk00<007`0O0002G`000<0
06mkKg/086mk00<007`0O0002G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/08Fmk00<0
07`0O0002G`00@00000?Kg/00`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l0009O0000`00Kg]_
N`09Kg/00`00O01l0009O0000`00Kg]_N`08Kg/00`00O01l0009O0000`00Kg]_N`09Kg/00`00O01l
0009O0000`00Kg]_N`0PKg/00`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l0009O0000`00Kg]_
N`0QKg/00`00O01l0009O001000000m_N`03001l07`000Ul0003001_Nfmk021_N`03001l07`000Ul
0003001_Nfmk00U_N`03001l07`000Ul0003001_Nfmk00Q_N`03001l07`000Ul0003001_Nfmk00U_
N`03001l07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003001_Nfmk021_N`03001l07`000Ul
0003001_Nfmk025_N`03001l07`000Ul004000003fmk00<007`0O0002G`000<006mkKg/086mk00<0
07`0O0002G`000<006mkKg/02Fmk3@002Vmk00<007`0O0002G`000<006mkKg/02Fmk00<007`0O000
2G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/0
8Fmk00<007`0O0002G`00@00000?Kg/00`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l0009O000
0`00Kg]_N`0PKg/00`00O01l0009O0000`00Kg]_N`09Kg/00`00O01l0009O0000`00Kg]_N`0PKg/0
0`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l0009O0000`00Kg]_N`0QKg/00`00O01l0009O001
000000m_N`03001l07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003001_Nfmk021_N`03001l
07`000Ul0003001_Nfmk00U_N`03001l07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003001_
Nfmk021_N`03001l07`000Ul0003001_Nfmk025_N`03001l07`000Ul004000003fmk00<007`0O000
2G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/0
2Fmk00<007`0O0002G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/086mk00<007`0O000
2G`000<006mkKg/08Fmk00<007`0O0002G`00@00000?Kg/00`00O01l0009O0000`00Kg]_N`0PKg/0
0`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l0009O0000`00Kg]_N`09Kg/00`00O01l0009O000
0`00Kg]_N`0PKg/00`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l0009O0000`00Kg]_N`0QKg/0
0`00O01l0009O001000000m_N`03001l07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003001_
Nfmk021_N`03001l07`000Ul0003001_Nfmk00U_N`03001l07`000Ul0003001_Nfmk021_N`03001l
07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003001_Nfmk025_N`03001l07`000Ul00400000
3fmk00<007`0O0002G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/086mk00<007`0O000
2G`000<006mkKg/02Fmk00<007`0O0002G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/0
86mk00<007`0O0002G`000<006mkKg/08Fmk00<007`0O0002G`00@00000?Kg/00`00O01l0009O000
0`00Kg]_N`0PKg/00`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l0009O0000`00Kg]_N`09Kg/0
0`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l0009O000
0`00Kg]_N`0QKg/00`00O01l0009O001000000m_N`03001l07`000Ul0003001_Nfmk021_N`03001l
07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003001_Nfmk00U_N`03001l07`000Ul0003001_
Nfmk021_N`03001l07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003001_Nfmk025_N`03001l
07`000Ul004000003fmk00<007`0O0002G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/0
86mk00<007`0O0002G`000<006mkKg/02Fmk00<007`0O0002G`000<006mkKg/086mk00<007`0O000
2G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/08Fmk00<007`0O0002G`00@00000?Kg/0
0`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l0009O000
0`00Kg]_N`09Kg/00`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l0009O0000`00Kg]_N`0PKg/0
0`00O01l0009O0000`00Kg]_N`0QKg/00`00O01l0009O001000000m_N`03001l07`000Ul0003001_
Nfmk021_N`03001l07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003001_Nfmk00U_N`03001l
07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003001_
Nfmk025_N`03001l07`000Ul004000003fmk00<007`0O0002G`000<006mkKg/086mk00<007`0O000
2G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/02Fmk00<007`0O0002G`000<006mkKg/0
86mk00<007`0O0002G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/08Fmk00<007`0O000
2G`00@00000?Kg/00`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l0009O0000`00Kg]_N`0PKg/0
0`00O01l0009O0000`00Kg]_N`09Kg/00`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l0009O000
0`00Kg]_N`0PKg/00`00O01l0009O0000`00Kg]_N`0QKg/00`00O01l0009O001000000m_N`03001l
07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003001_
Nfmk00U_N`03001l07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003001_Nfmk021_N`03001l
07`000Ul0003001_Nfmk025_N`03001l07`000Ul004000003fmk00<007`0O0002G`000<006mkKg/0
86mk00<007`0O0002G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/02Fmk00<007`0O000
2G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/0
8Fmk00<007`0O0002G`00@00000?Kg/00`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l0009O000
0`00Kg]_N`0PKg/00`00O01l0009O0000`00Kg]_N`09Kg/00`00O01l0009O0000`00Kg]_N`0PKg/0
0`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l0009O0000`00Kg]_N`0QKg/00`00O01l0009O001
000000m_N`03001l07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003001_Nfmk021_N`03001l
07`000Ul0003001_Nfmk00U_N`03001l07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003001_
Nfmk021_N`03001l07`000Ul0003001_Nfmk025_N`03001l07`000Ul0040000000=_N`0000000P00
0fmk0P001Fmk00<007`0O0002G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/086mk00<0
07`0O0002G`000<006mkKg/02Fmk3@008Vmk00<007`0O0002G`000<006mkKg/086mk00<007`0O000
2G`000<006mkKg/08Fmk00<007`0O0002G`00@0000000fmk001_N`04Kg/01000Kg]_N`0016mk00<0
07`0O0002G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/086mk00<007`0O0002G`000<0
06mkKg/0>6mk00<007`0O0002G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/08Fmk00<0
07`0O0002G`00@000002Kg/00`00Kg]_N`02Kg/01000Kg]_N`0016mk00<007`0O0002G`000<006mk
Kg/086mk00<007`0O0002G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/0>6mk00<007`0
O0002G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/08Fmk00<007`0O0002G`00@000003
Kg/01@00Kg]_Nfmk00000Vmk00<006mkKg/00Vmk00<007`0O0002G`000<006mkKg/086mk00<007`0
O0002G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/0>6mk00<007`0O0002G`000<006mk
Kg/086mk00<007`0O0002G`000<006mkKg/08Fmk00<007`0O0002G`00@0000001Fmk001_Nfmk0000
0Vmk00@006mkKg/000A_N`03001l07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003001_Nfmk
021_N`03001l07`000Ul0003001_Nfmk03Q_N`03001l07`000Ul0003001_Nfmk021_N`03001l07`0
00Ul0003001_Nfmk025_N`d000000Vmk0P0016mk0P001Fmk00<007`0O0002G`000<006mkKg/086mk
00<007`0O0002G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/0>6mk00<007`0O0002G`0
00<006mkKg/086mk00<007`0O0002G`000<006mkKg/0;Vmk000?Kg/00`00O01l0009O0000`00Kg]_
N`0PKg/00`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l0009O0000`00Kg]_N`0hKg/00`00O01l
0009O0000`00Kg]_N`0PKg/00`00O01l0009O0000`00Kg]_N`0^Kg/000m_N`03001l07`000Ul0003
001_Nfmk021_N`03001l07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003001_Nfmk03Q_N`03
001l07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003001_Nfmk02i_N`003fmk00<007`0O000
2G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/0
>6mk00<007`0O0002G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/0;Vmk000?Kg/00`00
O01l0009O0000`00Kg]_N`0PKg/00`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l0009O0000`00
Kg]_N`0hKg/00`00O01l0009O0000`00Kg]_N`0PKg/=000`Kg/000m_N`03001l07`000Ul0003001_
Nfmk021_N`03001l07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003001_Nfmk03Q_N`03001l
07`000Ul0003001_Nfmk05e_N`003fmk00<007`0O0002G`000<006mkKg/086mk00<007`0O0002G`0
00<006mkKg/086mk00<007`0O0002G`000<006mkKg/0>6mk00<007`0O0002G`000<006mkKg/0GFmk
000?Kg/00`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l
0009O0000`00Kg]_N`0hKg/00`00O01l0009O0000`00Kg]_N`1MKg/000m_N`03001l07`000Ul0003
001_Nfmk021_N`03001l07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003001_Nfmk03Q_N`03
001l07`000Ul0003001_Nfmk05e_N`003fmk00<007`0O0002G`000<006mkKg/086mk00<007`0O000
2G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/0>6mk00<007`0O0002G`000<006mkKg/0
GFmk000?Kg/00`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l0009O0000`00Kg]_N`0PKg/00`00
O01l0009O0000`00Kg]_N`0hKg/00`00O01l0009O0000`00Kg]_N`1MKg/000m_N`03001l07`000Ul
0003001_Nfmk021_N`03001l07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003001_Nfmk03Q_
N`03001l07`000Ul0003001_Nfmk05e_N`003fmk00<007`0O0002G`000<006mkKg/086mk00<007`0
O0002G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/0>6mk00<007`0O0002G`000<006mk
Kg/0GFmk000?Kg/00`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l0009O0000`00Kg]_N`0PKg/0
0`00O01l0009O0000`00Kg]_N`0hKg/00`00O01l0009O0000`00Kg]_N`1MKg/000m_N`03001l07`0
00Ul0003001_Nfmk021_N`03001l07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003001_Nfmk
03Q_N`03001l07`000Ul0003001_Nfmk05e_N`003fmk00<007`0O0002G`000<006mkKg/086mk00<0
07`0O0002G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/0>6mk00<007`0O0002G`000<0
06mkKg/0GFmk000?Kg/00`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l0009O0000`00Kg]_N`0P
Kg/00`00O01l0009O0000`00Kg]_N`0hKg/00`00O01l0009O0000`00Kg]_N`1MKg/000m_N`03001l
07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003001_
Nfmk03Q_N`03001l07`000Ul0003001_Nfmk05e_N`003fmk00<007`0O0002G`000<006mkKg/086mk
00<007`0O0002G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/0>6mk00<007`0O0002G`0
00<006mkKg/0GFmk000?Kg/00`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l0009O0000`00Kg]_
N`0PKg/00`00O01l0009O0000`00Kg]_N`0hKg/00`00O01l0009O0000`00Kg]_N`1MKg/000m_N`03
001l07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003
001_Nfmk03Q_N`03001l07`000Ul0003001_Nfmk05e_N`003fmk00<007`0O0002G`000<006mkKg/0
86mk00<007`0O0002G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/0>6mk00<007`0O000
2G`000<006mkKg/0GFmk000?Kg/00`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l0009O0000`00
Kg]_N`0PKg/00`00O01l0009O0000`00Kg]_N`0hKg/00`00O01l0009O0000`00Kg]_N`1MKg/000m_
N`03001l07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003001_Nfmk021_N`03001l07`000Ul
0003001_Nfmk03Q_N`03001l07`000Ul0003001_Nfmk05e_N`003fmk00<007`0O0002G`000<006mk
Kg/086mk00<007`0O0002G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/0>6mk00<007`0
O0002G`000<006mkKg/0GFmk000?Kg/00`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l0009O000
0`00Kg]_N`0PKg/00`00O01l0009O0000`00Kg]_N`0hKg/00`00O01l0009O0000`00Kg]_N`1MKg/0
00m_N`03001l07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003001_Nfmk021_N`03001l07`0
00Ul0003001_Nfmk03Q_N`03001l07`000Ul0003001_Nfmk05e_N`003fmk00<007`0O0002G`000<0
06mkKg/086mk00<007`0O0002G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/0>6mk00<0
07`0O0002G`000<006mkKg/0GFmk000?Kg/00`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l0009
O0000`00Kg]_N`0PKg/00`00O01l0009O0000`00Kg]_N`0hKg/00`00O01l0009O0000`00Kg]_N`1M
Kg/000m_N`03001l07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003001_Nfmk021_N`03001l
07`000Ul0003001_Nfmk03Q_N`03001l07`000Ul0003001_Nfmk05e_N`003fmk00<007`0O0002G`0
00<006mkKg/086mk00<007`0O0002G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/0>6mk
00<007`0O0002G`000<006mkKg/0GFmk000?Kg/00`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l
0009O0000`00Kg]_N`0PKg/00`00O01l0009O0000`00Kg]_N`0hKg/00`00O01l0009O0000`00Kg]_
N`1MKg/000=_N`<0009_N`8000E_N`03001l07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003
001_Nfmk021_N`03001l07`000Ul0003001_Nfmk03Q_N`03001l07`000Ul0003001_Nfmk05e_N`00
16mk00@006mkKg/0009_N`03001_Nfmk009_N`03001l07`000Ul0003001_Nfmk021_N`03001l07`0
00Ul0003001_Nfmk021_N`03001l07`000Ul0003001_Nfmk03Q_N`03001l07`000Ul0003001_Nfmk
05e_N`0000=_N`0000000`0000E_N`00Kg]_N`0000A_N`03001l07`000Ul0003001_Nfmk021_N`03
001l07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003001_Nfmk03Q_N`03001l07`000Ul0003
001_Nfmk05e_N`0000E_N`00Kg]_N`00009_N`04001_Nfmk0004Kg/00`00O01l0009O0000`00Kg]_
N`0PKg/00`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l0009O0000`00Kg]_N`0hKg/00`00O01l
0009O0000`00Kg]_N`1MKg/0009_N`03001_N`00009_N`04001_Nfmk0004Kg/00`00O01l0009O000
0`00Kg]_N`0PKg/00`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l0009O0000`00Kg]_N`0hKg/0
0`00O01l0009O0000`00Kg]_N`1MKg/000=_N`8000=_N`8000E_N`03001l07`000Ul0003001_Nfmk
021_N`03001l07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003001_Nfmk03Q_N`03001l07`0
00Ul0003001_Nfmk05e_N`003fmk00<007`0O0002G`000<006mkKg/086mk00<007`0O0002G`000<0
06mkKg/086mk00<007`0O0002G`000<006mkKg/0>6mk00<007`0O0002G`000<006mkKg/0GFmk000?
Kg/00`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l0009
O0000`00Kg]_N`0hKg/00`00O01l0009O0000`00Kg]_N`1MKg/000m_N`03001l07`000Ul0003001_
Nfmk021_N`03001l07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003001_Nfmk03Q_N`03001l
07`000Ul0003001_Nfmk05e_N`003fmk00<007`0O0002G`000<006mkKg/086mk00<007`0O0002G`0
00<006mkKg/086mk00<007`0O0002G`000<006mkKg/0>6mk00<007`0O0002G`000<006mkKg/0GFmk
000?Kg/00`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l0009O0000`00Kg]_N`0PKg/00`00O01l
0009O0000`00Kg]_N`0hKg/00`00O01l0009O0000`00Kg]_N`1MKg/000m_N`03001l07`000Ul0003
001_Nfmk021_N`03001l07`000Ul0003001_Nfmk021_N`03001l07`000Ul0003001_Nfmk03Q_N`03
001l07`000Ul0003001_Nfmk05e_N`003fmk00<007`0O0002G`000<006mkKg/086mk00<007`0O000
2G`000<006mkKg/086mk00<007`0O0002G`000<006mkKg/0>6mk00<007`0O0002G`000<006mkKg/0
GFmk000?Kg/00`00O01l0009O0000`00Kg]_N`0PKg/=000RKg/00`00O01l0009O0000`00Kg]_N`0h
Kg/00`00O01l0009O0000`00Kg]_N`1MKg/000m_N`03001l07`000Ul0003001_Nfmk04m_N`03001l
07`000Ul0003001_Nfmk03Q_N`03001l07`000Ul0003001_Nfmk05e_N`003fmk00<007`0O0002G`0
00<006mkKg/0Cfmk00<007`0O0002G`000<006mkKg/0>6mk00<007`0O0002G`000<006mkKg/0GFmk
000?Kg/00`00O01l0009O0000`00Kg]_N`1?Kg/00`00O01l0009O0000`00Kg]_N`0hKg/00`00O01l
0009O0000`00Kg]_N`1MKg/000m_N`03001l07`000Ul0003001_Nfmk04m_N`03001l07`000Ul0003
001_Nfmk03Q_N`03001l07`000Ul0003001_Nfmk05e_N`003fmk00<007`0O0002G`000<006mkKg/0
Cfmk00<007`0O0002G`000<006mkKg/0>6mk00<007`0O0002G`000<006mkKg/0GFmk000?Kg/00`00
O01l0009O0000`00Kg]_N`1?Kg/00`00O01l0009O0000`00Kg]_N`0hKg/00`00O01l0009O0000`00
Kg]_N`1MKg/000m_N`03001l07`000Ul0003001_Nfmk04m_N`03001l07`000Ul0003001_Nfmk03Q_
N`03001l07`000Ul0003001_Nfmk05e_N`003fmk00<007`0O0002G`000<006mkKg/0Cfmk00<007`0
O0002G`000<006mkKg/0>6mk00<007`0O0002G`000<006mkKg/0GFmk000?Kg/00`00O01l0009O000
0`00Kg]_N`1?Kg/00`00O01l0009O0000`00Kg]_N`0hKg/00`00O01l0009O0000`00Kg]_N`1MKg/0
00m_N`03001l07`000Ul0003001_Nfmk04m_N`03001l07`000Ul0003001_Nfmk03Q_N`03001l07`0
00Ul0003001_Nfmk05e_N`003fmk00<007`0O0002G`000<006mkKg/0Cfmk00<007`0O0002G`000<0
06mkKg/0>6mk00<007`0O0002G`000<006mkKg/0GFmk000?Kg/00`00O01l0009O0000`00Kg]_N`1?
Kg/00`00O01l0009O0000`00Kg]_N`0hKg/00`00O01l0009O0000`00Kg]_N`1MKg/000m_N`03001l
07`000Ul0003001_Nfmk04m_N`03001l07`000Ul0003001_Nfmk03Q_N`03001l07`000Ul0003001_
Nfmk05e_N`003fmk00<007`0O0002G`000<006mkKg/0Cfmk00<007`0O0002G`000<006mkKg/0>6mk
00<007`0O0002G`000<006mkKg/0GFmk000?Kg/00`00O01l0009O0000`00Kg]_N`1?Kg/00`00O01l
0009O0000`00Kg]_N`0hKg/00`00O01l0009O0000`00Kg]_N`1MKg/000m_N`03001l07`000Ul0003
001_Nfmk04m_N`03001l07`000Ul0003001_Nfmk03Q_N`03001l07`000Ul0003001_Nfmk05e_N`00
3fmk00<007`0O0002G`000<006mkKg/0Cfmk00<007`0O0002G`000<006mkKg/0>6mk00<007`0O000
2G`000<006mkKg/0GFmk000?Kg/00`00O01l0009O0000`00Kg]_N`1?Kg/00`00O01l0009O0000`00
Kg]_N`0hKg/00`00O01l0009O0000`00Kg]_N`1MKg/000m_N`03001l07`000Ul0003001_Nfmk04m_
N`03001l07`000Ul0003001_Nfmk03Q_N`03001l07`000Ul0003001_Nfmk05e_N`003fmk00<007`0
O0002G`000<006mkKg/0Cfmk00<007`0O0002G`000<006mkKg/0>6mk00<007`0O0002G`000<006mk
Kg/0GFmk000?Kg/00`00O01l0009O0000`00Kg]_N`1?Kg/00`00O01l0009O0000`00Kg]_N`0hKg/0
0`00O01l0009O0000`00Kg]_N`1MKg/000m_N`03001l07`000Ul0003001_Nfmk04m_N`03001l07`0
00Ul0003001_Nfmk03Q_N`d005m_N`003fmk00<007`0O0002G`000<006mkKg/0Cfmk00<007`0O000
2G`000<006mkKg/0Y6mk000016mk0000000016mk0P001Fmk00<007`0O0002G`000<006mkKg/0Cfmk
00<007`0O0002G`000<006mkKg/0Y6mk00001Fmk001_Nfmk00000Vmk00@006mkKg/000A_N`03001l
07`000Ul0003001_Nfmk04m_N`03001l07`000Ul0003001_Nfmk0:A_N`0000E_N`00Kg]_N`00009_
N`04001_Nfmk0004Kg/00`00O01l0009O0000`00Kg]_N`1?Kg/00`00O01l0009O0000`00Kg]_N`2T
Kg/00004Kg/000000003Kg/01000Kg]_N`0016mk00<007`0O0002G`000<006mkKg/0Cfmk00<007`0
O0002G`000<006mkKg/0Y6mk0002Kg/00`00Kg]_N`02Kg/01000Kg]_N`0016mk00<007`0O0002G`0
00<006mkKg/0Cfmk00<007`0O0002G`000<006mkKg/0Y6mk0002Kg/30003Kg/20005Kg/00`00O01l
0009O0000`00Kg]_N`1?Kg/00`00O01l0009O0000`00Kg]_N`2TKg/000m_N`03001l07`000Ul0003
001_Nfmk04m_N`03001l07`000Ul0003001_Nfmk0:A_N`003fmk00<007`0O0002G`000<006mkKg/0
Cfmk00<007`0O0002G`000<006mkKg/0Y6mk000?Kg/00`00O01l0009O0000`00Kg]_N`1?Kg/00`00
O01l0009O0000`00Kg]_N`2TKg/000m_N`03001l07`000Ul0003001_Nfmk04m_N`d00:I_N`003fmk
00<007`0O0002G`000<006mkKg/0ofmk0fmk000?Kg/00`00O01l0009O0000`00Kg]_N`3oKg/3Kg/0
00m_N`03001l07`000Ul0003001_Nfmk0?m_N`=_N`003fmk00<007`0O0002G`000<006mkKg/0ofmk
0fmk000?Kg/00`00O01l0009O0000`00Kg]_N`3oKg/3Kg/000m_N`03001l07`000Ul0003001_Nfmk
0?m_N`=_N`003fmk00<007`0O0002G`000<006mkKg/0ofmk0fmk000?Kg/00`00O01l0009O0000`00
Kg]_N`3oKg/3Kg/000m_N`03001l07`000Ul0003001_Nfmk0?m_N`=_N`003fmk00<007`0O0002G`0
00<006mkKg/0ofmk0fmk000?Kg/00`00O01l0009O0000`00Kg]_N`3oKg/3Kg/000m_N`03001l07`0
00Ul0003001_Nfmk0?m_N`=_N`003fmk00<007`0O0002G`000<006mkKg/0ofmk0fmk000?Kg/00`00
O01l0009O0000`00Kg]_N`3oKg/3Kg/000m_N`03001l07`000Ul0003001_Nfmk0?m_N`=_N`003fmk
00<007`0O0002G`000<006mkKg/0ofmk0fmk000?Kg/00`00O01l0009O0000`00Kg]_N`3oKg/3Kg/0
00m_N`03001l07`000Ul0003001_Nfmk0?m_N`=_N`003fmk00<007`0O0002G`000<006mkKg/0ofmk
0fmk000?Kg/00`00O01l0009O0000`00Kg]_N`3oKg/3Kg/000m_N`03001l07`000Ul0003001_Nfmk
0?m_N`=_N`003fmk00<007`0O0002G`000<006mkKg/0ofmk0fmk000?Kg/00`00O01l0009O0000`00
Kg]_N`3oKg/3Kg/000m_N`03001l07`000Ul0003001_Nfmk0?m_N`=_N`003fmk00<007`0O0002G`0
00<006mkKg/0ofmk0fmk000?Kg/00`00O01l0009O0000`00Kg]_N`3oKg/3Kg/0009_N`8000A_N`80
00E_N`03001l07`000Ul0003001_Nfmk0?m_N`=_N`0000E_N`00Kg]_N`00009_N`04001_Nfmk0004
Kg/00`00O01l0009O0000`00Kg]_N`3oKg/3Kg/00005Kg/006mkKg/00002Kg/01000Kg]_N`0016mk
00<007`0O0002G`000<006mkKg/0ofmk0fmk0002Kg/20003Kg/01000Kg]_N`0016mk00<007`0O000
2G`000<006mkKg/0ofmk0fmk00001Fmk001_Nfmk00000Vmk00@006mkKg/000A_N`03001l07`000Ul
0003001_Nfmk0?m_N`=_N`000Vmk0P0016mk0P001Fmk00<007`0O0002G`000<006mkKg/0ofmk0fmk
000?Kg/00`00O01l0009O0000`00Kg]_N`3oKg/3Kg/000m_N`03001l07`000Ul0003001_Nfmk0?m_
N`=_N`003fmk00<007`0O0002G`000<006mkKg/0ofmk0fmk000?Kg/00`00O01l0009O0000`00Kg]_
N`3oKg/3Kg/000m_N`03001l07`000Ul0003001_Nfmk0?m_N`=_N`003fmk00<007`0O0002G`000<0
06mkKg/0ofmk0fmk000?Kg/00`00O01l0009O0000`00Kg]_N`3oKg/3Kg/000m_N`03001l07`000Ul
0003001_Nfmk0?m_N`=_N`003fmk00<007`0O0002G`000<006mkKg/0ofmk0fmk000?Kg/=003oKg/5
Kg/000m_N`03001_Nfmk0?m_N`m_N`003fmk00<006mkKg/0ofmk3fmk000?Kg/00`00Kg]_N`3oKg/?
Kg/000m_N`03001_Nfmk0?m_N`m_N`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.651904, -6.93033, \
0.0423413, 0.544205}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
In the next example we calculate the polyphony (number of simultaneous notes) \
at a given tick. This is not the most efficient algorithm but it does the \
trick.\
\>", "Text"],

Cell[BoxData[
    \(Polyphony[el_, tick_] := 
      Length[Select[Cases[el, {_, _Note}], 
          First[#1] \[LessEqual] tick && 
              First[#1] + #1\[LeftDoubleBracket]2, 2\[RightDoubleBracket] > 
                tick &]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Polyphony[l, 2003]\)], "Input"],

Cell[BoxData[
    \(3\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Experimentation", "Subsection"],

Cell[TextData[{
  "We will use Arun Chandras Music package that comes with ",
  StyleBox["Mathematica.",
    FontSlant->"Italic"]
}], "Text"],

Cell[BoxData[
    \(<< Miscellaneous`Music`\)], "Input"],

Cell[CellGroupData[{

Cell["Notes of a given pitch", "Subsubsection"],

Cell["\<\
Here we create a new Event called PitchedNote that produces a given frequency \
using the PitchBend and Note events. We convert the frequency to a Note \
Number plus a Pitch Bend value. This is implemented as a rule.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PitchRule = {t_, PitchedNote[pitch_, dur_, vel_, ch_]} \[RuleDelayed] 
        Module[{notenum = 69 + Round[First[HertzToCents[{440, x}]/100]]}, 
          Sequence @@ {{t, 
                PitchBend[
                  Round[\((8192/
                          200)\) \(HertzToCents[{8.1758\ 2^\((notenum/12)\), 
                            pitch}]\)[\([1]\)]], ch]}, {t, 
                Note[notenum, dur, vel, ch]}, {t + dur, 
                PitchBend[0, ch]}}]\)], "Input"],

Cell[BoxData[
    \({t_, PitchedNote[pitch_, dur_, vel_, ch_]} \[RuleDelayed] 
      Module[{notenum = 69 + Round[First[1\/100\ HertzToCents[{440, x}]]]}, 
        Sequence @@ {{t, 
              PitchBend[
                Round[8192\/200\ \(HertzToCents[{8.1758`\ 2\^\(notenum/12\), 
                          pitch}]\)\[LeftDoubleBracket]1\[RightDoubleBracket]]\
, ch]}, {t, Note[notenum, dur, vel, ch]}, {t + dur, 
              PitchBend[0, ch]}}]\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(ExportMIDI[{{0, PitchedNote[456, whole, 100, 1]}} /. 
        PitchRule, "\<output.mid\>"]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Scales", "Subsubsection"],

Cell["\<\
We use the PitchedNote event to define a function that plays the scales from \
the music package. For simpliicity all scales begin at 440 Hz (A).\
\>", "Text"],

Cell[BoxData[
    \(PlayScaleMIDI[scale_, file_String] := 
      ExportMIDI[
        EventSequence[
            PitchedNote[\(CentsToHertz[scale]\)[\([i]\)], eighth, 100, 1], 
            quarter, {i, 1, Length[scale]}] /. PitchRule, file]\)], "Input"],

Cell["This is the Pythagorean Major scale.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(?PythagoreanMajor\)\), "\[IndentingNewLine]", 
    \(PlayScaleMIDI[PythagoreanMajor, "\<output.mid\>"]\)}], "Input"],

Cell[BoxData[
    \("PythagoreanMajor is an interval list in which the members of the scale \
are derived from a sequence of octaves and fifths, where a fifth is the ratio \
of 3/2 (702 cents) and an octave is the ratio of 2/1 (1200 cents).  The scale \
is built by successive fifth addition and octave subtraction."\)], "Print"]
}, Open  ]],

Cell["This is the Pythagorean Chromatic scale.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(?PythagoreanChromatic\)\), "\[IndentingNewLine]", 
    \(PlayScaleMIDI[PythagoreanChromatic, "\<output.mid\>"]\)}], "Input"],

Cell[BoxData[
    \("PythagoreanChromatic is an interval list that is an extension of the \
PythagoreanMajor scale.  It has 21 notes, since the complete scale requires 7 \
\"natural\" notes, 7 \"flat\" notes, and 7 \"sharp\" notes."\)], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["The corkscrew effect", "Subsubsection"],

Cell[TextData[{
  "Here is how we can construct an ever-falling tone (this is a famous \
example, there is even an old english documentary that shows a piano with \
midi capabilities (a Bosendorfer I think) programmed to play it). The ear \
follows one of the falliing sequences just like the eye follows one of the \
helixes of a revolving corkscrew. Really easy to program with ",
  StyleBox["Musica",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[BoxData[
    \(ExportMIDI[
      Join @@ Table[
          EventSequence[
            Note[120 - Mod[i - 12  j, 120], sixteenth, 
              Round[127\ \ Sin[\ Pi\ Mod[i - 12  j, 120]/120]], 1], 
            sixteenth, {i, 0, 119}], {j, 0, 9}], "\<output.mid\>"]\)], "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Info", "Section"],

Cell[TextData[{
  "This is the first version of Musica - consider it a beta version.\nPlease \
let me know: \n- if you found any bugs\n- if you have any suggestions, ideas \
or a wish list\n- if you find Musica helpful and use it frequently\n- if you \
have used Musica in any project\n- if you have some examples that can be \
included and help other users of Musica\n \n At this point I do not really \
know how many ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " users are interested in the Math/Music combination. If I see that Musica \
is usefull to a considerable amount of users I will evolve it to a more \
complete package (I have many ideas for the next versions: MIDI file format 1 \
support, a complete set of MIDI effects and editing functions, a MIDI to wave \
rendering utility - to create your own synths and render MIDI files with them \
just like csound, maybe even a realtime extension). However the only way to \
know that people are using Musica is your feedback - so keep it coming!"
}], "Text",
  TextAlignment->Left],

Cell[TextData[StyleBox[" Costis Merziotis (Athens, Greece) \
cmerziotis@hotmail.com",
  FontSize->16]], "Section 1"]
}, Closed]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 800}, {0, 547}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{792, 513},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1,
StyleDefinitions -> "Report.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 106, 3, 83, "Title",
  Evaluatable->False],
Cell[1826, 54, 61, 1, 23, "Commentary"],
Cell[1890, 57, 160, 7, 40, "Subtitle",
  Evaluatable->False],
Cell[2053, 66, 89, 1, 69, "Section 1"],

Cell[CellGroupData[{
Cell[2167, 71, 33, 0, 67, "Section"],
Cell[2203, 73, 187, 5, 55, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[2427, 83, 31, 0, 41, "Section"],
Cell[2461, 85, 4762, 88, 658, "Text"],

Cell[CellGroupData[{
Cell[7248, 177, 55, 1, 41, "Subsection",
  Evaluatable->False],
Cell[7306, 180, 1449, 22, 199, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[8804, 208, 27, 0, 41, "Section"],
Cell[8834, 210, 527, 9, 53, "Commentary"],

Cell[CellGroupData[{
Cell[9386, 223, 67, 0, 41, "Subsection"],
Cell[9456, 225, 844, 14, 114, "Text"],
Cell[10303, 241, 89, 2, 35, "Input",
  Evaluatable->False],
Cell[10395, 245, 415, 7, 80, "Text"],
Cell[10813, 254, 310, 9, 140, "Program"],
Cell[11126, 265, 71, 0, 29, "Text"],
Cell[11200, 267, 155, 5, 72, "Program"],
Cell[11358, 274, 213, 4, 46, "Text"],
Cell[11574, 280, 77, 1, 25, "DisplayFormula"],
Cell[11654, 283, 211, 4, 46, "Text"],
Cell[11868, 289, 251, 12, 191, "Program"],
Cell[12122, 303, 449, 7, 80, "Text"],
Cell[12574, 312, 165, 6, 89, "Program"],
Cell[12742, 320, 466, 7, 80, "Text"],
Cell[13211, 329, 158, 13, 208, "Program"],
Cell[13372, 344, 126, 2, 35, "Input"],
Cell[13501, 348, 112, 3, 29, "Text"],
Cell[13616, 353, 1579, 24, 495, "Input"],
Cell[15198, 379, 418, 7, 63, "Text"],

Cell[CellGroupData[{
Cell[15641, 390, 80, 1, 35, "Input"],
Cell[15724, 393, 2093, 50, 384, "Output"]
}, Open  ]],
Cell[17832, 446, 274, 5, 46, "Text"],
Cell[18109, 453, 76, 1, 35, "Input"],
Cell[18188, 456, 210, 4, 46, "Text"],
Cell[18401, 462, 93, 1, 35, "Input"],
Cell[18497, 465, 502, 10, 63, "Text"],
Cell[19002, 477, 123, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[19150, 484, 75, 1, 35, "Input"],
Cell[19228, 487, 139, 3, 40, "Print"],
Cell[19370, 492, 139, 3, 40, "Print"],
Cell[19512, 497, 137, 3, 40, "Print"],
Cell[19652, 502, 2134, 50, 384, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[21835, 558, 57, 0, 25, "Subsection"],
Cell[21895, 560, 336, 6, 63, "Text"],
Cell[22234, 568, 99, 2, 21, "Program"],
Cell[22336, 572, 308, 5, 46, "Text"],
Cell[22647, 579, 277, 6, 75, "Input"],
Cell[22927, 587, 655, 10, 97, "Text"],
Cell[23585, 599, 74, 1, 35, "Input"],
Cell[23662, 602, 289, 5, 46, "Text"],
Cell[23954, 609, 122, 2, 25, "DisplayFormula"],
Cell[24079, 613, 244, 4, 46, "Text"],
Cell[24326, 619, 247, 5, 75, "Input"],
Cell[24576, 626, 401, 6, 63, "Text"],
Cell[24980, 634, 339, 6, 95, "Input"],
Cell[25322, 642, 425, 8, 80, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[25784, 655, 49, 0, 25, "Subsection"],
Cell[25836, 657, 192, 5, 29, "Text"],

Cell[CellGroupData[{
Cell[26053, 666, 502, 9, 115, "Input"],
Cell[26558, 677, 335, 5, 87, "Output"]
}, Open  ]],
Cell[26908, 685, 308, 5, 46, "Text"],

Cell[CellGroupData[{
Cell[27241, 694, 79, 2, 35, "Input"],
Cell[27323, 698, 250, 4, 68, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27610, 707, 103, 2, 35, "Input"],
Cell[27716, 711, 186, 3, 68, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27939, 719, 104, 2, 35, "Input"],
Cell[28046, 723, 88, 2, 49, "Output"]
}, Open  ]],
Cell[28149, 728, 429, 7, 63, "Text"],
Cell[28581, 737, 127, 5, 72, "Program"],

Cell[CellGroupData[{
Cell[28733, 746, 76, 2, 35, "Input"],
Cell[28812, 750, 184, 3, 68, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29033, 758, 75, 2, 35, "Input"],
Cell[29111, 762, 315, 5, 87, "Output"]
}, Open  ]],
Cell[29441, 770, 233, 4, 46, "Text"],

Cell[CellGroupData[{
Cell[29699, 778, 97, 2, 35, "Input"],
Cell[29799, 782, 405, 7, 106, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30241, 794, 98, 2, 35, "Input"],
Cell[30342, 798, 360, 6, 87, "Output"]
}, Open  ]],
Cell[30717, 807, 124, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[30866, 814, 91, 2, 35, "Input"],
Cell[30960, 818, 295, 5, 87, "Output"]
}, Open  ]],
Cell[31270, 826, 170, 3, 46, "Text"],
Cell[31443, 831, 63, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[31531, 835, 146, 4, 35, "Input"],
Cell[31680, 841, 357, 6, 87, "Output"]
}, Open  ]],
Cell[32052, 850, 130, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[32207, 857, 129, 3, 35, "Input"],
Cell[32339, 862, 363, 6, 87, "Output"]
}, Open  ]],
Cell[32717, 871, 65, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[32807, 875, 105, 2, 35, "Input"],
Cell[32915, 879, 364, 6, 87, "Output"]
}, Open  ]],
Cell[33294, 888, 215, 4, 46, "Text"],

Cell[CellGroupData[{
Cell[33534, 896, 193, 4, 55, "Input"],
Cell[33730, 902, 560, 9, 125, "Output"]
}, Open  ]],
Cell[34305, 914, 219, 4, 46, "Text"],

Cell[CellGroupData[{
Cell[34549, 922, 231, 5, 75, "Input"],
Cell[34783, 929, 403, 6, 106, "Output"]
}, Open  ]],
Cell[35201, 938, 193, 4, 46, "Text"],

Cell[CellGroupData[{
Cell[35419, 946, 235, 6, 55, "Input"],
Cell[35657, 954, 4771, 110, 77, 881, 57, "GraphicsData", "PostScript", \
"Graphics"],
Cell[40431, 1066, 155, 4, 49, "Output"]
}, Open  ]],
Cell[40601, 1073, 203, 4, 46, "Text"],

Cell[CellGroupData[{
Cell[40829, 1081, 213, 5, 55, "Input"],
Cell[41045, 1088, 1360, 19, 277, "Output"]
}, Open  ]],
Cell[42420, 1110, 509, 8, 80, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[42966, 1123, 42, 0, 25, "Subsection"],
Cell[43011, 1125, 815, 13, 114, "Text"],

Cell[CellGroupData[{
Cell[43851, 1142, 166, 2, 55, "Input"],
Cell[44020, 1146, 172, 3, 49, "Output"]
}, Open  ]],
Cell[44207, 1152, 141, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[44373, 1159, 233, 5, 75, "Input"],
Cell[44609, 1166, 301, 6, 87, "Output"]
}, Open  ]],
Cell[44925, 1175, 268, 5, 46, "Text"],

Cell[CellGroupData[{
Cell[45218, 1184, 89, 1, 35, "Input"],
Cell[45310, 1187, 224, 4, 68, "Output"]
}, Open  ]],
Cell[45549, 1194, 226, 4, 55, "Input"],
Cell[45778, 1200, 91, 2, 29, "Text"],
Cell[45872, 1204, 155, 3, 55, "Input"],
Cell[46030, 1209, 419, 8, 63, "Text"],

Cell[CellGroupData[{
Cell[46474, 1221, 514, 9, 115, "Input"],
Cell[46991, 1232, 466, 8, 106, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47494, 1245, 61, 1, 35, "Input"],
Cell[47558, 1248, 147, 2, 49, "Output"]
}, Open  ]],
Cell[47720, 1253, 274, 5, 46, "Text"],

Cell[CellGroupData[{
Cell[48019, 1262, 104, 2, 35, "Input"],
Cell[48126, 1266, 810, 14, 163, "Output"]
}, Open  ]],
Cell[48951, 1283, 947, 14, 131, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[49947, 1303, 27, 0, 41, "Section"],
Cell[49977, 1305, 471, 12, 63, "Text"],

Cell[CellGroupData[{
Cell[50473, 1321, 39, 0, 41, "Subsection"],
Cell[50515, 1323, 293, 7, 46, "Text"],

Cell[CellGroupData[{
Cell[50833, 1334, 43, 0, 31, "Subsubsection"],
Cell[50879, 1336, 231, 4, 46, "Text"],
Cell[51113, 1342, 364, 7, 95, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[51514, 1354, 45, 0, 25, "Subsubsection"],
Cell[51562, 1356, 429, 9, 63, "Text"],
Cell[51994, 1367, 274, 6, 75, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[52317, 1379, 34, 0, 25, "Subsection"],
Cell[52354, 1381, 134, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[52513, 1388, 38, 0, 31, "Subsubsection"],
Cell[52554, 1390, 182, 4, 46, "Text"],
Cell[52739, 1396, 64, 0, 29, "Text"],
Cell[52806, 1398, 128, 3, 35, "Input"],
Cell[52937, 1403, 97, 2, 29, "Text"],
Cell[53037, 1407, 151, 3, 55, "Input"],
Cell[53191, 1412, 128, 3, 29, "Text"],
Cell[53322, 1417, 148, 3, 55, "Input"],
Cell[53473, 1422, 123, 3, 29, "Text"],
Cell[53599, 1427, 268, 5, 95, "Input"],
Cell[53870, 1434, 141, 3, 29, "Text"],
Cell[54014, 1439, 226, 5, 75, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[54277, 1449, 43, 0, 25, "Subsubsection"],
Cell[54323, 1451, 351, 6, 63, "Text"],
Cell[54677, 1459, 296, 5, 46, "Text"],
Cell[54976, 1466, 285, 5, 95, "Input"],
Cell[55264, 1473, 229, 4, 46, "Text"],
Cell[55496, 1479, 417, 8, 155, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[55950, 1492, 34, 0, 25, "Subsubsection"],
Cell[55987, 1494, 170, 3, 46, "Text"],
Cell[56160, 1499, 288, 6, 95, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[56497, 1511, 29, 0, 25, "Subsection"],
Cell[56529, 1513, 58, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[56612, 1517, 56, 0, 31, "Subsubsection"],
Cell[56671, 1519, 106, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[56802, 1526, 75, 1, 35, "Input"],
Cell[56880, 1529, 139, 3, 40, "Print"],
Cell[57022, 1534, 139, 3, 40, "Print"],
Cell[57164, 1539, 137, 3, 40, "Print"]
}, Open  ]],
Cell[57316, 1545, 122, 3, 29, "Text"],
Cell[57441, 1550, 232, 4, 75, "Input"],
Cell[57676, 1556, 99, 2, 29, "Text"],
Cell[57778, 1560, 139, 3, 35, "Input"],
Cell[57920, 1565, 314, 5, 63, "Text"],
Cell[58237, 1572, 207, 5, 75, "Input"],
Cell[58447, 1579, 309, 5, 46, "Text"],
Cell[58759, 1586, 265, 6, 75, "Input"],
Cell[59027, 1594, 105, 3, 29, "Text"],
Cell[59135, 1599, 172, 4, 55, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[59344, 1608, 37, 0, 25, "Subsubsection"],
Cell[59384, 1610, 145, 3, 29, "Text"],
Cell[59532, 1615, 88, 2, 29, "Text"],
Cell[59623, 1619, 216, 4, 75, "Input"],
Cell[59842, 1625, 76, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[59943, 1629, 151, 2, 55, "Input"],
Cell[60097, 1633, 293, 4, 87, "Output"]
}, Open  ]],
Cell[60405, 1640, 282, 5, 46, "Text"],
Cell[60690, 1647, 245, 5, 75, "Input"],
Cell[60938, 1654, 795, 11, 114, "Text"],
Cell[61736, 1667, 296, 6, 75, "Input"],
Cell[62035, 1675, 130, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[62190, 1682, 89, 1, 35, "Input"],
Cell[62282, 1685, 1950, 32, 619, "Output"]
}, Closed]],
Cell[64247, 1720, 917, 13, 129, "Text"],
Cell[65167, 1735, 366, 6, 63, "Text"],
Cell[65536, 1743, 253, 6, 75, "Input"],
Cell[65792, 1751, 172, 3, 55, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[66013, 1760, 30, 0, 25, "Subsection"],
Cell[66046, 1762, 274, 6, 46, "Text"],

Cell[CellGroupData[{
Cell[66345, 1772, 75, 1, 35, "Input"],
Cell[66423, 1775, 139, 3, 40, "Print"],
Cell[66565, 1780, 139, 3, 40, "Print"],
Cell[66707, 1785, 137, 3, 40, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[66881, 1793, 102, 2, 35, "Input"],
Cell[66986, 1797, 28568, 727, 194, 5695, 440, "GraphicsData", "PostScript", \
"Graphics"],
Cell[95557, 2526, 130, 3, 49, "Output"]
}, Open  ]],
Cell[95702, 2532, 186, 4, 46, "Text"],
Cell[95891, 2538, 246, 5, 55, "Input"],

Cell[CellGroupData[{
Cell[96162, 2547, 51, 1, 35, "Input"],
Cell[96216, 2550, 35, 1, 49, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[96300, 2557, 37, 0, 25, "Subsection"],
Cell[96340, 2559, 141, 4, 29, "Text"],
Cell[96484, 2565, 56, 1, 35, "Input"],

Cell[CellGroupData[{
Cell[96565, 2570, 47, 0, 31, "Subsubsection"],
Cell[96615, 2572, 240, 4, 46, "Text"],

Cell[CellGroupData[{
Cell[96880, 2580, 497, 9, 115, "Input"],
Cell[97380, 2591, 465, 8, 141, "Output"]
}, Open  ]],
Cell[97860, 2602, 123, 2, 35, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[98020, 2609, 31, 0, 31, "Subsubsection"],
Cell[98054, 2611, 169, 3, 46, "Text"],
Cell[98226, 2616, 252, 5, 75, "Input"],
Cell[98481, 2623, 52, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[98558, 2627, 139, 2, 55, "Input"],
Cell[98700, 2631, 329, 4, 97, "Print"]
}, Open  ]],
Cell[99044, 2638, 56, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[99125, 2642, 147, 2, 55, "Input"],
Cell[99275, 2646, 245, 3, 78, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[99569, 2655, 45, 0, 25, "Subsubsection"],
Cell[99617, 2657, 447, 9, 63, "Text"],
Cell[100067, 2668, 282, 6, 115, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[100410, 2681, 23, 0, 41, "Section"],
Cell[100436, 2683, 1052, 17, 233, "Text"],
Cell[101491, 2702, 116, 2, 68, "Section 1"]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

